#!/usr/bin/env python
from org.noora.processor.ProcessorException import ProcessorException

class Processable:
  
  def __init__(self):
    pass
 
  def call(self, callable):
    raise ProcessorException("method not implemented") 
  







#!/usr/bin/env python
from org.noora.parser.ParserException import ParserException

class PreProcessable:
  def __init__(self):
    pass

  def parse(self, parsable=None):
    raise ParserException("method not implemented")





#!/usr/bin/env python

import core.Plugin as Plugin
import core.VersionHelper as VersionHelper
import core.NooraException as NooraException
import os
import subprocess
from connectors.SqlLoaderConnector import SqlLoaderConnector
from connectors.LoadJavaConnector import LoadJavaConnector


class UpdatePlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setSqlLoaderConnector(SqlLoaderConnector())
    self.setLoadJavaConnector(LoadJavaConnector())
    self.setType("UPDATE")
    
    self.addParameterDefinition('database',['-s','-si','--sid'])
    self.addParameterDefinition('scheme',['-u','-sc','--scheme'])
    self.addParameterDefinition('environment',['-e','--env'])
    self.addParameterDefinition('version',['-v','--version'])

  def setSqlLoaderConnector(self, connector):
    self.__sqlLoaderConnector = connector
  
  def getSqlLoaderConnector(self):
    return self.__sqlLoaderConnector

  def setLoadJavaConnector(self, connector):
    self.__loadJavaConnector = connector
  
  def getLoadJavaConnector(self):
    return self.__loadJavaConnector


  def getDescription(self):
    return "executes the defined update scripts in the alter folders."

  def getUsage(self):  
    print "Noora database installer, update.py"
    print self.getDescription()
    print "-s= --sid=     required, contains the tnsname of the database."
    print "-v= --version= required, contains the version of the update"
    print "                         to execute"
    print "-u= --scheme=  not required, contains the scheme of "
    print "                             the database objects to drop."
    print "-e= --env=     not required, used for mapping "
    print "                             the username and password."
    print "-nocompile     not required, disable the compilation of "
    print "                             packages, triggers and views."

  def getPluginDir(self):
    return self.getNooraDir()+os.sep+'plugins'+os.sep+'static'+os.sep+'update'

  def getPreviousVersion(self, versions, version):

    index=versions.index(version)
    if index>0:
      previousVersion=versions[index-1]
      return previousVersion    
    return None
  
  def getDefaultVersion(self):
    configReader=self.getConfigReader()
    defaultVersion=configReader.getValue('DEFAULT_VERSION')
    return defaultVersion
  
  def getVersions(self, defaultVersion):
    projectHelper=self.getProjectHelper()    
    versions=[]
    alterFolder=projectHelper.getAlterFolder()
    if projectHelper.folderPresent(alterFolder):
      versions=projectHelper.findFolders(alterFolder)
    createFolder=projectHelper.getCreateFolder()
    if projectHelper.folderPresent(createFolder):
      versions.append(defaultVersion)
   
    #versionHelper=VersionHelper.VersionHelper(versions)
    #versions=versionHelper.sort()
    versions.sort()    
    return versions
    


  def installComponent(self, url, oracleSid, oracleUser, oraclePasswd):
    projectHelper=self.getProjectHelper()
    handle=open('feedback.log','wb')
    result=subprocess.call(['python',url+os.sep+'setup.py','-s='+oracleSid,'-u='+oracleUser,'-p='+oraclePasswd,'-silent'],shell=False,stdout=handle,stderr=handle)
    if result!=0:
      stream=projectHelper.readFile('feedback.log')
      raise NooraException.NooraException(stream)


  def installFiles(self, folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors):
    connector=self.getConnector()
    projectHelper=self.getProjectHelper()
    files=projectHelper.findFiles(folder)
    for file in files:
      url=folder+os.sep+file
      print url.split(self.getBaseDir())[1]
      if projectHelper.getFileExtension(file).lower()=='zip':
        projectHelper.extractFile(url)
        extractFolder=projectHelper.getFileRoot(url)
        self.installComponent(extractFolder,oracleSid,oracleUser,oraclePasswd)
        projectHelper.removeFolderRecursive(extractFolder)
      elif projectHelper.getFileExtension(file).lower()=='jar':
        loadJavaConnector = self.getLoadJavaConnector()
        loadJavaConnector.execute(oracleSid, oracleUser, oraclePasswd, url,'','', ignoreErrors)
      else:
        connector.execute(oracleSid, oracleUser, oraclePasswd, url,'','', ignoreErrors)        


  def loadFiles(self, folder, oracleSid, oracleUser, oraclePasswd, ctlFile, ignoreErrors):   
    connector=self.getSqlLoaderConnector()
    projectHelper=self.getProjectHelper() 
    files=projectHelper.findFiles(folder)
    for file in files:
      url=folder+os.sep+file
      print url.split(self.getBaseDir())[1]
      if projectHelper.getFileExtension(file).lower()=='zip':
        projectHelper.extractFile(url,projectHelper.getFileRoot(file))
        
        for extractedFile in projectHelper.findFiles(folder+os.sep+projectHelper.getFileRoot(file)):
          connector.execute(oracleSid, oracleUser, oraclePasswd, ctlFile, extractedFile, ignoreErrors)
        projectHelper.removeFolderRecursive(folder+os.sep+projectHelper.getFileRoot(file))
      elif projectHelper.getFileExtension(file).lower()=='mdl':
        pass
      elif projectHelper.getFileExtension(file).lower()=='jar':
        loadJavaConnector = self.getLoadJavaConnector()
        loadJavaConnector.execute(oracleSid, oracleUser, oraclePasswd, url, '', '', ignoreErrors)        
      else:
        connector.execute(oracleSid, oracleUser, oraclePasswd, ctlFile, folder + os.sep + file, ignoreErrors)  




  def checkVersion(self, oracleSid,oracleUser,oraclePasswd,previousVersion, versionSelectStatement, ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getPluginDir()+os.sep+'checkversion.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,previousVersion,versionSelectStatement,ignoreErrors)

  def checkEnvironment(self, oracleSid,oracleUser,oraclePasswd, environment, environmentSelectStatement, ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getPluginDir()+os.sep+'checkenvironment.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,environment,environmentSelectStatement, ignoreErrors)

  def recompile(self, oracleSid, oracleUser, oraclePasswd, ignoreErrors):    
    connector=self.getConnector()
    oracleScript=self.getScriptDir()+os.sep+'recompile.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,'','', ignoreErrors)

    

  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    

    ignoreErrors=False  
    if  parameterHelper.hasParameter('-ignore_errors')==True:
      ignoreErrors=True      

    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()

    oracleSid=parameterHelper.getParameterValue(['-s=','--sid='],[])
    projectHelper.failOnEmpty(oracleSid,'no oracle sid was given.')
    configReader.failOnValueNotFound('ORACLE_SIDS',oracleSid,'the given oracle sid is not valid for this project.')
    oracleSid=oracleSid[0]
    
    schemes=configReader.getValue('SCHEMES')
    projectHelper.failOnNone(schemes,'the variable SCHEMES is not set.')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    environment=configReader.getValue('DEFAULT_ENVIRONMENT')
    projectHelper.failOnNone(environment,'the variable DEFAULT_ENVIRONMENT is not set.')
    environment=parameterHelper.getParameterValue(['-e=','--env='],[environment])
    projectHelper.failOnEmpty(environment,'no environment was found')
    configReader.failOnValueNotFound('ENVIRONMENTS',environment,'the given environment is not valid for this project.')
    environment=environment[0]

    objects = configReader.getValue('CREATE_OBJECTS')
    projectHelper.failOnNone(objects,'the variable CREATE_OBJECTS is not set.')
    projectHelper.failOnEmpty(environment,'the variable CREATE_OBJECTS is not set.')

    defaultVersion=self.getDefaultVersion()
    projectHelper.failOnNone(defaultVersion,'the variable DEFAULT_VERSION is not set.')
    projectHelper.failOnEmpty(defaultVersion,'the variable DEFAULT_VERSION is not configured for this project.')

    version=parameterHelper.getParameterValue(['-v=','--version='],[])
    projectHelper.failOnEmpty(version,'no version was given')
    
    # find the versions
    versions=self.getVersions(defaultVersion)  
        
    version=version[0]
    projectHelper.failOnValueNotFound(versions,version,'the given version is not valid for this project.')
        
    projectHelper.failOnFolderNotPresent(self.getAlterDir()+os.sep+version,'the update folder for this version is not present.')

    previousVersion=self.getPreviousVersion(versions,version)    
    projectHelper.failOnNone(previousVersion,'the previous version of this version could not be found.')

    versionScheme=configReader.getValue('VERSION_SCHEME')
    projectHelper.failOnNone(previousVersion,'the variable VERSION_SCHEME is not set.')
    oracleUser=projectHelper.getOracleUser(oracleSid, versionScheme)
    oraclePasswd=projectHelper.getOraclePasswd(oracleSid, versionScheme)

    versionSelectStatement=configReader.getValue('VERSION_SELECT_STATEMENT')
    projectHelper.failOnNone(versionSelectStatement,'the variable VERSION_SELECT_STATEMENT is not set.')
    environmentSelectStatement=configReader.getValue('ENVIRONMENT_SELECT_STATEMENT')
    projectHelper.failOnNone(versionSelectStatement,'the variable ENVIRONMENT_SELECT_STATEMENT is not set.')
    self.checkVersion(oracleSid,oracleUser,oraclePasswd,previousVersion,versionSelectStatement, ignoreErrors)
    self.checkEnvironment(oracleSid,oracleUser,oraclePasswd,environment,environmentSelectStatement, ignoreErrors)

    for scheme in schemes:

      print "updating scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
      oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
      oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)

      for object in objects:

        # global ddl objects
        folder=self.getAlterDir()+os.sep+version+os.sep+scheme+os.sep+'ddl'+os.sep+object
        if projectHelper.folderPresent(folder):
          self.installFiles(folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors)
      
        # environment specific ddl objects
        folder=self.getAlterDir()+os.sep+version+os.sep+scheme+os.sep+'ddl'+os.sep+object+os.sep+environment
        if projectHelper.folderPresent(folder):
          self.installFiles(folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors)

      # global dat objects
      folder=self.getAlterDir()+os.sep+version+os.sep+scheme+os.sep+'dat'
      if projectHelper.folderPresent(folder):
        self.installFiles(folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors)

      # environment specific dat objects
      folder=self.getAlterDir()+os.sep+version+os.sep+scheme+os.sep+'dat'+os.sep+environment
      if projectHelper.folderPresent(folder):
        self.installFiles(folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors)
   
      # global sqlldr files
      folder=self.getAlterDir()+os.sep+version+os.sep+scheme+os.sep+'sqlldr'
      if projectHelper.folderPresent(folder):
        ctlFolders = projectHelper.findFolders(folder)
        for ctlFolder in ctlFolders:
          ctlFile = folder+os.sep+ctlFolder+os.sep+ctlFolder+".ctl"
          self.loadFiles(folder+os.sep+ctlFolder, oracleSid, oracleUser, oraclePasswd, ctlFile, ignoreErrors)

      # environment sqlldr files
      folder=self.getAlterDir()+os.sep+version+os.sep+scheme+os.sep+'sqlldr'
      if projectHelper.folderPresent(folder):
        ctlFolders = projectHelper.findFolders(folder)
        for ctlFolder in ctlFolders:
          ctlFile = folder+os.sep+ctlFolder + os.sep + environment + os.sep + ctlFolder+ ".ctl"
          envFolder=folder + os.sep + ctlFolder + os.sep + environment
          if projectHelper.folderPresent(envFolder):          
            self.loadFiles(envFolder, oracleSid, oracleUser, oraclePasswd, ctlFile, ignoreErrors)

   
   
   
      print "scheme '"+scheme+"' updated."

    if  parameterHelper.hasParameter('-nocompile')==False:
      for scheme in schemes:
        print "compiling scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
        oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
        oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
        self.recompile(oracleSid,oracleUser,oraclePasswd, ignoreErrors)
        print "scheme '"+scheme+"' compiled."





#!/usr/bin/env python
from org.noora.io.IOException import IOException

class Writeable:
  
  def __init__(self):
    pass
  
  def fileno(self):
    raise IOException("method not implemented")
  
  def write(self, buffer):  
    raise IOException("method not implemented")
  
  def close(self):
    raise IOException("method not implemented")



       





#!/usr/bin/env python
from org.noora.plugin.oracle.drop.DropPlugin import DropPlugin as OracleDropPlugin
from org.noora.plugin.mysql.drop.DropPlugin import DropPlugin as MySqlDropPlugin

class PluginFactory:
  def __init__(self):
    pass
  
  @staticmethod
  def newOracleDropPlugin(connectable):
    return OracleDropPlugin(connectable)
  
  @staticmethod
  def newMySqlDropPlugin(connectable):
    return MySqlDropPlugin(connectable)



class NooraException(Exception):
    
    def __init__(self, message):
        self.__message=message

    def __str__(self):
        return repr(self.__message)

    def getMessage(self):
        return self.__message



#!/usr/bin/env python
from org.noora.connector.Execute import Execute

__revision__ = "$Revision: $"


class MysqlExecute(Execute):

  def __init__(self):
    Execute.__init__(self)
    self.__host = None
    self.__database = None
    self.__username = None
    self.__password = None
        
  def setHost(self, host):
    self.__host=host

  def getHost(self):
    return self.__host

  def setDatabase(self, database):
    self.__database=database

  def getDatabase(self):
    return self.__database
  
  def setUsername(self, username):
    self.__username=username

  def getUsername(self):
    return self.__username
  
  def setPassword(self, password):
    self.__password=password

  def getPassword(self):
    return self.__password    

    
    




#!/usr/bin/env python
from org.noora.connector.ConnectorException import ConnectorException

__revision__ = "$Revision: $"


class Executable:

  def __init__(self):
    pass
    
  def setIgnoreErrors(self, ignoreErrors):
    raise ConnectorException("method not implemented")        

  def getIgnoreErrors(self):
    raise ConnectorException("method not implemented")        
    
  def setScript(self, script):
    raise ConnectorException("method not implemented")

  def getScript(self):
    raise ConnectorException("method not implemented")



#!/usr/bin/env python

import core.Connector as Connector
import os
import subprocess
import core.NooraException as NooraException
import logging

class OracleConnector(Connector.Connector):
  
  def __init__(self):
    Connector.Connector.__init__(self)
  
  def getScriptDir(self):
    return self.getNooraDir()+os.sep+'scripts'

  def getStartupInfo(self):
    startupInfo=None
    if os.name=='nt':    
      startupInfo=subprocess.STARTUPINFO()
      #USESHOWWINDOW
      startupInfo.dwFlags |=1
      #SW_HIDE
      startupInfo.wShowWindow=0
    return startupInfo

  def getDatabases(self):
    projectHelper=self.getProjectHelper()
    url=os.getenv('TNS_ADMIN')+os.sep+"tnsnames.ora"
    stream=projectHelper.readFile(url)
    print stream
    
  
  def execute(self, oracleSid, oracleUser, oraclePasswd, oracleScript, paramA, paramB, ignoreErrors):
    try:
      startupInfo=self.getStartupInfo()
      projectHelper=self.getProjectHelper()
      handle=open('feedback.log','wb')
      connectString=oracleUser+'/'+oraclePasswd+'@'+oracleSid
      templateScript='@'+projectHelper.cleanPath(self.getScriptDir()+os.sep+'template.sql')
      result=subprocess.call(['sqlplus','-l','-s',connectString , templateScript, projectHelper.cleanPath(oracleScript), paramA, paramB],shell=False,stdout=handle,stderr=handle,startupinfo=startupInfo)
      stream=projectHelper.readFile('feedback.log')
     
      
      logger = logging.getLogger('NoOraLogger')
      logger.info(oracleScript)
      if result!=0:  
        #stream = StreamHelper.StreamHelper().convert(stream)
        #stream = stream.replace(chr(10),chr(32))     
        logger.error(stream)
        if ignoreErrors==False:
          raise NooraException.NooraException(stream)
      else:
        logger.info(stream)
    except OSError:
      raise NooraException.NooraException("Could not execute sqlplus. Is it installed and in your path?")







#!/usr/bin/env python

class MissingOptionException(Exception):
    
  def __init__(self, message, missingOptions):
    Exception.__init__(self)
            
    self.__missingOptions=missingOptions
    for missingOption in missingOptions:
      message = message + " " + missingOption.getType() + ","
      message = message.rstrip(',')
    self.__message=message  

  def __str__(self):
    return repr(self.__message)

  def getMessage(self):
    return self.__message
  
  def getMissingOptions(self):
    return self.__missingOptions



#!/usr/bin/env python

from org.noora.plugin.Plugin import Plugin
from org.noora.helper.PropertyHelper import PropertyHelper
from org.noora.io.File import File
from org.noora.cl.OptionFactory import OptionFactory
from org.noora.plugin.ConnectionExecutor import ConnectionExecutor
from org.noora.connector.ExecuteFactory import ExecuteFactory
import os

class DropPlugin(Plugin):
  def __init__(self, connectable):
    Plugin.__init__(self, "DROP", connectable)

  def getDescription(self):
    return "drops database objects in oracle databases."

  def getDropDir(self, properties):
    return properties.getPropertyValue('noora.dir')+os.sep+'org'+os.sep+'noora'+os.sep+'plugin'+os.sep+'oracle'+os.sep+'drop'

  def getOptions(self, properties):
    options = Plugin.getOptions(self)
    
    options.addOption("-?", "--help", False, False,  "display help")      
    
    option = OptionFactory.newOption("-s", "--sid", True, True, "tns name of the oracle database.")
    option.setValues(properties.getPropertyValues('ORACLE_SIDS'))
    options.add(option)
    
    option = OptionFactory.newOption("-u", "--user", True, False, "user in the oracle database.")
    option.setValues(properties.getPropertyValues('SCHEMES'))
    options.add(option)
    
    option = OptionFactory.newOption("-e", "--environment", True, False, "environment descriptor of the oracle database.")
    option.setValues(properties.getPropertyValues('ENVIRONMENTS'))
    options.add(option)
    
#    options.addOption("--no-compile", True, False, "disable the compilation of database objects.")
    options.addOption("-i", "--ignore-errors", True, False, "ignore errors.")
    return options
  

  def execute(self, commandLine, properties):

    ignoreErrors = commandLine.getOptionValue('--ignore-errors', False)
    host = commandLine.getOptionValue('-s')

    defaultSchemes = properties.getPropertyValues('SCHEMES')
    schemes = commandLine.getOptionValues('-u', defaultSchemes)

    defaultEnvironment = properties.getProperty('DEFAULT_ENVIRONMENT')
    environment = commandLine.getOptionValue('-e', defaultEnvironment)

    objects = properties.getPropertyValues('DROP_OBJECTS')

    connector=self.getConnector()
    
    
    for scheme in schemes:
      print "dropping scheme '"+scheme+"' in database '" + host +"' using environment '"+environment+"'"      
      users= properties.getPropertyValues('ORACLE_USERS')
      user = PropertyHelper.getUser(users, host, scheme)
      passwd = PropertyHelper.getPasswd(users, host, scheme)      
      
      executor = ExecuteFactory.newOracleExecute()
      executor.setHost(host)
      executor.setIgnoreErrors(ignoreErrors)
      executor.setPassword(passwd)
      executor.setUsername(user)      
      
      for object in objects:
        
        folder=File(self.getDropDir(properties)+os.sep+object)        
        ConnectionExecutor.execute(connector, executor, properties, folder)

      print "scheme '"+scheme+"' dropped."





#!/usr/bin/env python
from org.noora.connector.ConnectorException import ConnectorException

__revision__ = "$Revision: $"


class Connectable:

  def __init__(self):
    pass
    
  def execute(self, executable):
    raise ConnectorException("method not implemented")




import wx
import os
import sys
import AbstractFrame           as AbstractFrame
import panels.ActionPanel      as ActionPanel
import panels.HeaderPanel      as HeaderPanel
import core.ConfigReader       as ConfigReader
import core.ParameterHelper    as ParameterHelper
import core.Redirect           as Redirect
import core.NooraException     as NooraException
import core.CommandDispatcher  as CommandDispatcher
import core.PluginFinishedEvent as PluginFinishedEvent
import MainMenuBar             as MainMenuBar
import MainToolBar             as MainToolBar
import Settings                as Settings
import NewProjectDialog        as NewProjectDialog
import EditProjectDialog       as EditProjectDialog
import wx.lib.agw.flatnotebook as FlatNoteBook
import MainArtProvider         as MainArtProvider
import traceback

NOORA_DIR    = os.path.abspath(os.path.dirname(sys.argv[0]))
PLUGIN_DIR   = NOORA_DIR+os.sep+'plugins'
sys.path.append(PLUGIN_DIR)


class MainFrame(AbstractFrame.AbstractFrame):

  def getNotebook(self):
    return self.__notebook
  
  def getConsoleViewIndex(self):
    notebook=self.getNotebook()
    pageCount=notebook.GetPageCount()
    for pageIndex in range(pageCount):
      if notebook.GetPageText(pageIndex).lower()=='console':
        return pageIndex
  
  def getActionViewIndex(self):
    notebook=self.getNotebook()
    pageCount=notebook.GetPageCount()
    for pageIndex in range(pageCount):
      if notebook.GetPageText(pageIndex).lower()=='action':
        return pageIndex
    

  def getParameterHelper(self):
    parameterHelper=ParameterHelper.ParameterHelper()
    return parameterHelper
  
  def getActionControl(self):
    return self.__actionControl  
  
  def getConsole(self):
    return self.__console
  
  def getHeaderControl(self):
    return self.__headerControl

  def getDescriptionControl(self):
    actionControl=self.getActionControl()
    return actionControl.getDesciptionControl()
  
  def getDatabaseControl(self):
    actionControl=self.getActionControl()
    return actionControl.getDatabaseControl()

  def getSchemeControl(self):
    actionControl=self.getActionControl()
    return actionControl.getSchemeControl()
  
  def getEnvironmentControl(self):
    actionControl=self.getActionControl()
    return actionControl.getEnvironmentControl()

  def getVersionControl(self):
    actionControl=self.getActionControl()
    return actionControl.getVersionControl()

  def getCommandControl(self):
    actionControl=self.getActionControl()
    return actionControl.getCommandControl()
  
  def setConfigReader(self, configReader):
    self.__configReader=configReader
    
  def getConfigReader(self):
    return self.__configReader
      
  def getCommandDispatcher(self):
    return self.__commandDispatcher
  
  def setCommandDispatcher(self, commandDispatcher):
    self.__commandDispatcher=commandDispatcher
    
  def __init__(self, parent, title):

    AbstractFrame.AbstractFrame.__init__(self, parent, title)		
    
    mainMenuBar=MainMenuBar.MainMenuBar()
    self.SetMenuBar(mainMenuBar)
    mainToolBar=MainToolBar.MainToolBar(self,-1)
    self.SetToolBar(mainToolBar)
    mainToolBar.Realize()
    sizer=wx.BoxSizer(wx.VERTICAL)
    actionPanel = wx.Panel(self,-1)
    
    self.__headerControl = HeaderPanel.HeaderPanel(actionPanel, -1,"NoOra Project","")
    self.__notebook = FlatNoteBook.FlatNotebook(actionPanel,-1,style=FlatNoteBook.FNB_FF2)
    style=self.__notebook.GetWindowStyleFlag()
    style|=FlatNoteBook.FNB_VC8
    self.__notebook.SetAGWWindowStyleFlag(style)
    images=wx.ImageList(16, 16)

    image=MainArtProvider.MainArtProvider.GetBitmap(Settings.ART_CONSOLE, wx.ART_TOOLBAR, (16, 16))
    images.Add(image)
    
    image=MainArtProvider.MainArtProvider.GetBitmap(Settings.ART_ACTION, wx.ART_TOOLBAR, (16, 16))
    images.Add(image)
    
    
    self.__notebook.SetImageList(images)
    self.__actionControl = ActionPanel.ActionPanel(self.__notebook,-1)
    self.__console = wx.TextCtrl(self.__notebook,-1,style=wx.TE_MULTILINE)
    self.__console.SetEditable(False)
    
    self.__notebook.AddPage(self.__actionControl,'Action',True,1)
    self.__notebook.AddPage(self.__console,'Console',True,0)
    self.__notebook.SetSelection(0)
    redirect=Redirect.Redirect(self.__console)
    sys.stdout=redirect
    sys.stderr=redirect
    
    sizer.Add(self.__headerControl,0,wx.EXPAND)
    sizer.Add(self.__notebook,1,wx.EXPAND)
    
    actionPanel.SetSizer(sizer)
    
    self.Bind(wx.EVT_BUTTON, self.onOpenProject, id=Settings.ID_OPEN_PROJECT) 
    self.Bind(wx.EVT_MENU, self.onOpenProject, id=Settings.ID_OPEN_PROJECT)
    self.Bind(wx.EVT_MENU, self.onNewProject, id=Settings.ID_NEW_PROJECT)
    self.Bind(wx.EVT_MENU, self.onAbout, id=wx.ID_ABOUT)
    self.Bind(wx.EVT_MENU, self.onExit, id=wx.ID_EXIT)
    self.Bind(wx.EVT_MENU, self.onEditProject, id=Settings.ID_EDIT_PROJECT)
    self.Bind(wx.EVT_MENU, self.onShowActionView, id=Settings.ID_SHOW_ACTION_VIEW)
    self.Bind(wx.EVT_MENU, self.onShowConsoleView, id=Settings.ID_SHOW_CONSOLE_VIEW)

    self.Bind(wx.EVT_TOOL, self.onOpenProject, id=Settings.ID_OPEN_PROJECT)
    self.Bind(wx.EVT_TOOL, self.onNewProject, id=Settings.ID_NEW_PROJECT)
    self.Bind(wx.EVT_TOOL, self.onExecute, id=Settings.ID_EXECUTE)   
    self.Bind(wx.EVT_TOOL, self.onClear, id=Settings.ID_CLEAR)

    
    self.Connect(Settings.ID_OPEN_PROJECT, -1, Settings.EVT_PLUGIN_FINISHED, self.openProject)
    self.Bind(wx.EVT_COMBOBOX, self.onCommandChanged, id=Settings.ID_COMMAND)
    #self.Bind(Settings.EVT_PLUGIN_FINISHED, self.openProject, id=Settings.ID_OPEN_PROJECT)
    self.Bind(wx.EVT_CLOSE, self.onClose)
    self.__statusBar = self.CreateStatusBar();
    self.__statusBar.SetStatusText("To create a new project, click on New Project in the Project menu")
    

  def onNewProject(self, evt): 
    try:
      newProjectDialog = NewProjectDialog.NewProjectDialog(self, -1, 'New Project')
      result = newProjectDialog.ShowModal()
      if result == Settings.ID_FINISH:
        os.chdir(newProjectDialog.getDirectory())
        
        configReader=ConfigReader.ConfigReader(NOORA_DIR+os.sep+"project.conf")
        self.setConfigReader(configReader)
        
        commandDispatcher=CommandDispatcher.CommandDispatcher(configReader) 
        self.setCommandDispatcher(commandDispatcher)
        
        executionContext = commandDispatcher.createExecutionContext(self, Settings.ID_OPEN_PROJECT,"generate") 
        executionContext.addExecutionParameter("project", newProjectDialog.getDirectory()+os.sep+newProjectDialog.getProject())      
        executionContext.addExecutionParameter("database", newProjectDialog.getDatabase())
        executionContext.addExecutionParameter("scheme", newProjectDialog.getScheme())
        executionContext.addExecutionParameter("username", newProjectDialog.getUsername())
        executionContext.addExecutionParameter("password", newProjectDialog.getPassword())
        executionContext.addExecutionParameter("version", newProjectDialog.getVersion())
        

        
        commandDispatcher.execute(executionContext)
        
        
             
      newProjectDialog.Destroy()
    except NooraException.NooraException as e: 
      newProjectDialog.Destroy()     
      print e.getMessage()
    except:
      newProjectDialog.Destroy()
      print traceback.print_exc()


  def openProject(self, evt):  
    directory=evt.getDirectory()
    filename=evt.getFilename()

    headerControl=self.getHeaderControl()
    headerControl.getDescriptionControl().SetLabel(directory)
      
    os.chdir(directory)
    
    configReader=ConfigReader.ConfigReader(directory+os.sep+filename)
    self.setConfigReader(configReader)
    
    commandDispatcher=CommandDispatcher.CommandDispatcher(configReader) 
    self.setCommandDispatcher(commandDispatcher)
          
    commandControl=self.getCommandControl()
    commandControl.clear()
    commandControl.setValue("")  
    commandControl.Enable(True)      
    pluginTypes=commandDispatcher.getPluginTypes()
    commandControl.appendItems(pluginTypes)
      
    databases = configReader.getValue('ORACLE_SIDS')
    databaseControl=self.getDatabaseControl()
    databaseControl.setItems(databases)
    
    schemes = configReader.getValue('SCHEMES')
    schemeControl=self.getSchemeControl()
    schemeControl.setItems(schemes)
        
    environments = configReader.getValue('ENVIRONMENTS')
    defaultEnvironment = configReader.getValue('DEFAULT_ENVIRONMENT')
    environmentControl=self.getEnvironmentControl()
    environmentControl.setItems(environments)
    environmentControl.setValue(defaultEnvironment)  
        

  def onOpenProject(self, evt): 
    openDialog = wx.FileDialog(self, "Choose a NoOra project file", "", "", "NoOra project files (project.conf)|project.conf", wx.OPEN)  
    if openDialog.ShowModal() == wx.ID_OK:          
      directory,filename=os.path.split(openDialog.GetPath())        
      wx.PostEvent(self, PluginFinishedEvent.PluginFinishedEvent(Settings.ID_OPEN_PROJECT,directory, filename))   
    openDialog.Destroy()

    
  def onEditProject(self, evt):
    headerControl=self.getHeaderControl()
    directory=headerControl.getDescriptionControl().GetLabel()
    url=directory + os.sep + 'project.conf'
    
    editProjectDialog = EditProjectDialog.EditProjectDialog(self, -1, 'Edit project.conf', url)
    result = editProjectDialog.ShowModal()
    if result == Settings.ID_FINISH:
      pass

  def onExecute(self, evt):
    try:
      configReader=self.getConfigReader()
      command=self.getCommandControl().getValue()
      commandDispatcher=CommandDispatcher.CommandDispatcher(configReader)
      
      executionContext = commandDispatcher.createExecutionContext(self, Settings.ID_EXECUTE, command) 
      
      executionContext.addExecutionParameter("database", self.getDatabaseControl().getValue())
      executionContext.addExecutionParameter("scheme", self.getSchemeControl().getValue())
      executionContext.addExecutionParameter("environment", self.getEnvironmentControl().getValue())
      executionContext.addExecutionParameter("version", self.getVersionControl().getValue())

      commandDispatcher.execute(executionContext)
      
      notebook=self.getNotebook()
      consoleViewIndex=self.getConsoleViewIndex()
      notebook.SetSelection(consoleViewIndex)
      
          
    except NooraException.NooraException as e:      
      print e.getMessage()
    except:
      print traceback.print_exc()

  def onClear(self, evt):
    console=self.getConsole()
    console.Clear()  
    
  def onAbout(self, evt):
    info = wx.AboutDialogInfo()
    info.Name = "NoOra Gui"
    info.Version = "0.0.8.2"
    info.Description ="NoOra is an attempt to apply a pattern to installing/updating Oracle database projects\r\nin order to promote portability and productivity. "
    info.Copyright = "(L) 2010, 2011, 2012, 2013 NoOra"
    info.WebSite = ("https://sourceforge.net/p/noora/wiki/Home/", "NoOra home page")
    info.Developers = [ "Jan Ripke","Peter Kist" ]
    wx.AboutBox(info)
    
  def onExit(self, evt):
    self.Close(True);   
    
  def onClose(self, evt):
    self.Destroy()

  def onCommandChanged(self, evt):
    configReader=self.getConfigReader()
    commandDispatcher=CommandDispatcher.CommandDispatcher(configReader)
    plugin = commandDispatcher.getPlugin(self.getCommandControl().getValue())
    
    descriptionControl=self.getDescriptionControl()
    descriptionControl.SetLabel(plugin.getDescription())
    
    if plugin.findParameterDefinition('database'):
      self.getDatabaseControl().Enable(True)
    else:
      self.getDatabaseControl().Enable(False)
      
    if plugin.findParameterDefinition('scheme'):
      self.getSchemeControl().Enable(True)
    else:
      self.getSchemeControl().Enable(False)      
      
    if plugin.findParameterDefinition('environment'):
      self.getEnvironmentControl().Enable(True)
    else:
      self.getEnvironmentControl().Enable(False)     
      
    if plugin.findParameterDefinition('version'): 
      versionControl=self.getVersionControl()
      versionControl.Enable(True)
      defaultVersion=plugin.getDefaultVersion()
          
      versions=plugin.getVersions(defaultVersion)
      versionControl.setItems(versions)            
      versionControl.setValue(versions[len(versions)-1])
      
    else:
      self.getVersionControl().Enable(False)

  def onShowActionView(self, evt):
    notebook=self.getNotebook()
    actionViewIndex=self.getActionViewIndex()
    if actionViewIndex==None:      
      self.__actionControl = ActionPanel.ActionPanel(notebook,-1)
      notebook.AddPage(self.__actionControl,'Action',True,1)
      actionViewIndex=self.getActionViewIndex()
    notebook.SetSelection(actionViewIndex)
    directory=self.getHeaderControl().getDescriptionControl().GetLabel()
    filename='project.conf'
    wx.PostEvent(self, PluginFinishedEvent.PluginFinishedEvent(Settings.ID_OPEN_PROJECT,directory, filename))
    
    
  def onShowConsoleView(self, evt):
    notebook=self.getNotebook()
    consoleViewIndex=self.getConsoleViewIndex()
    if consoleViewIndex==None:      
      self.__console = wx.TextCtrl(notebook,-1,style=wx.TE_MULTILINE)
      self.__console.SetEditable(False)
      redirect=Redirect.Redirect(self.__console)
      sys.stdout=redirect
      sys.stderr=redirect
      notebook.AddPage(self.__console,'Console',True,0)
      consoleViewIndex=self.getActionViewIndex()
    notebook.SetSelection(consoleViewIndex)
    
    
      


#!/usr/bin/env python

class UnknownVersionException(Exception):
    
  def __init__(self, message, version):
    Exception.__init__(self)            
    self.__version=version    
    message = message + " " + version 
    self.__message=message  

  def __str__(self):
    return repr(self.__message)

  def getMessage(self):
    return self.__message
  
  def getUnknownVersion(self):
    return self.__version



#!/usr/bin/env python
from org.noora.cl.Option import Option

class OptionFactory:
  def __init__(self):
    pass
  
  @staticmethod
  def newOption(type=None, longType=None, hasArguments=False, required=False, description=None):
    return Option(type, longType, hasArguments, required, description)



#!/usr/bin/env python
import core.MysqlPlugin as MysqlPlugin
import os
import subprocess
import core.NooraException as NooraException

class MysqlCreatePlugin(MysqlPlugin.MysqlPlugin):
  def __init__(self):
    MysqlPlugin.MysqlPlugin.__init__(self)
    self.setType("CREATE")

    self.addParameterDefinition('host',['-h','--host'])
    self.addParameterDefinition('database',['-s','-database'])
    self.addParameterDefinition('environment',['-e','--env'])
    

  def getDescription(self):
    return "executes the defined baseline scripts in the create folder."

  def getUsage(self):  
    print "NoOra database installer, MysqlCreatePlugin"
    print self.getDescription()
    print "-h= --host=      required contains the hostname of the mysql-server."
    print "-d= --database=  not required contains the database."
    print "-e= --env=       not required, used for mapping "
    print "                               the username and password."
    print "-nocompile       not required, disable the compilation of "
    print "                 packages, triggers and views."

  
  def getCreateDir(self):
    return self.getBaseDir()+os.sep+'create'


  def installComponent(self, url, mysqlHost, database, mysqlUser, mysqlPasswd):
    projectHelper=self.getProjectHelper()
    handle=open('feedback.log','wb')
    result=subprocess.call(['python',url+os.sep+'setup.py','-h='+mysqlHost,'-d='+database,'-u='+mysqlUser,'-p='+mysqlPasswd,'-silent'],shell=False,stdout=handle,stderr=handle)
    if result!=0:
      stream=projectHelper.readFile('feedback.log')
      raise NooraException.NooraException(stream)


  def installFiles(self, folder, mysqlHost, database, mysqlUser, mysqlPasswd, ignoreErrors):
    connector=self.getConnector()
    projectHelper=self.getProjectHelper()
    files=projectHelper.findFiles(folder)
    for file in files:
      url=folder+os.sep+file
      print url.split(self.getBaseDir())[1]
      if projectHelper.getFileExtension(file).lower()=='zip':
        projectHelper.extractFile(url)
        extractFolder=projectHelper.getFileRoot(url)
        self.installComponent(extractFolder,mysqlHost,database,mysqlUser,mysqlPasswd)
        projectHelper.removeFolderRecursive(extractFolder)
      elif projectHelper.getFileExtension(file).lower()=='mdl':
        pass
      else:
        connector.execute(mysqlHost, database, mysqlUser, mysqlPasswd, url, '', '', ignoreErrors)  


  def recompile(self, mysqlHost, database, mysqlUser, mysqlPasswd, ignoreErrors):
    connector=self.getConnector()
    mysqlScript=self.getScriptDir()+os.sep+'mysql_recompile.sql'
    connector.execute(mysqlHost, database, mysqlUser, mysqlPasswd, mysqlScript, '', '', ignoreErrors)
    

  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    
    
    ignoreErrors=False  
    if  parameterHelper.hasParameter('-ignore_errors')==True:
      ignoreErrors=True
    print ignoreErrors      

    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()

    mysqlHost=parameterHelper.getParameterValue(['-h=','--host='],[])
    projectHelper.failOnEmpty(mysqlHost,'no mysql host was given.')
    configReader.failOnValueNotFound('MYSQL_HOSTS',mysqlHost,'the given mysql host is not valid for this project.')
    mysqlHost=mysqlHost[0]
    
    databases=configReader.getValue('DATABASES')
    projectHelper.failOnNone(databases,'the variable DATABASES is not set.')
    databases=parameterHelper.getParameterValue(['-d=','--database='],databases)
    configReader.failOnValueNotFound('DATABASES',databases,'the given database is not valid for this project.')

    environment=configReader.getValue('DEFAULT_ENVIRONMENT')
    environment=parameterHelper.getParameterValue(['-e=','--env='],[environment])
    projectHelper.failOnEmpty(environment,'no environment was found')
    configReader.failOnValueNotFound('ENVIRONMENTS',environment,'the given environment is not valid for this project.')
    environment=environment[0]

    objects = configReader.getValue('CREATE_OBJECTS')
    projectHelper.failOnNone(objects,'the variable CREATE_OBJECTS is not set.')
    projectHelper.failOnEmpty(objects,'the variable CREATE_OBJECTS is not set.')

    for database in databases:
      print "creating database '"+database+"' in mysql-server '"+mysqlHost+"' using environment '"+environment+"'"
      mysqlUser=projectHelper.getMysqlUser(mysqlHost, database)
      mysqlPasswd=projectHelper.getMysqlPasswd(mysqlHost, database)
 
      for object in objects:  

        # global ddl objects
        folder=self.getCreateDir()+os.sep+database+os.sep+'ddl'+os.sep+object
        if projectHelper.folderPresent(folder):
          self.installFiles(folder, mysqlHost, database, mysqlUser, mysqlPasswd, ignoreErrors)

        # environment specific ddl objects
        folder=self.getCreateDir()+os.sep+database+os.sep+'ddl'+os.sep+object+os.sep+environment
        if projectHelper.folderPresent(folder):
          self.installFiles(folder, mysqlHost, database, mysqlUser, mysqlPasswd, ignoreErrors)

      # global dat objects
      folder=self.getCreateDir()+os.sep+database+os.sep+'dat'
      if projectHelper.folderPresent(folder):
        self.installFiles(folder, mysqlHost, database, mysqlUser, mysqlPasswd, ignoreErrors)

      # environment specific dat objects
      folder=self.getCreateDir()+os.sep+database+os.sep+'dat'+os.sep+environment
      if projectHelper.folderPresent(folder):
        self.installFiles(folder, mysqlHost, database, mysqlUser, mysqlPasswd, ignoreErrors)
    
      print "database '"+database+"' created."

    #if  parameterHelper.hasParameter('-nocompile')==False:
    #  for database in databases:
    #    print "compiling database '"+database+"' in mysql-server '"+mysqlHost+"' using environment '"+environment+"'"
    #    mysqlUser=projectHelper.getMysqlUser(mysqlHost, database)
    #    mysqlPasswd=projectHelper.getMysqlPasswd(mysqlHost, database)
    #    self.recompile(mysqlHost,database, mysqlUser, mysqlPasswd, ignoreErrors)
    #    print "scheme '"+database+"' compiled."







import wx

class LabelText:
    '''
    This class contains a pair of a label and text field
    '''
    
    def _init_controls (self, parent, pos, labelWidth, textWidth, label, value):
        
        labelPos = wx.Point (pos.x, pos.y + 4);
        textPos = wx.Point (pos.x + labelWidth + 4, pos.y)
        
        self.labelid = wx.NewId()
        self.labelName = label + '_label'
        self.textid = wx.NewId()
        self.textName = label + '_text'
        
        self.label = wx.StaticText(id=self.labelid, label=label,
                                   name=self.labelName, parent=parent, 
                                   pos=labelPos,
                                   size=wx.Size(labelWidth, 13), style=0)

        self.text = wx.TextCtrl(id=self.textid,
                                name=self.textName, parent=parent,
                                pos=textPos, size=wx.Size(textWidth, 21),
                                style=0, value=value)
        
        
    def __init__(self, parent, pos, labelWidth, textWidth, label, value):
        self._init_controls(parent, pos, labelWidth, textWidth, label, value)
        


#Boa:Frame:TopFrame

import gui.Action
import gui.ProjectDialog
import AbstractFrame
import wx
import wx.stc


[ID_NEW_PROJECT, ID_PROJECT_DLG, 
 ID_OPEN_PROJECT, ID_CLOSE_PROJECT, ID_EXIT
] = [wx.NewId() for _init_ctrls in range(5)]
[ID_CMD_CREATE, ID_CMD_RECREATE, ID_CMD_UPDATE, ID_CMD_PREPARE
] = [wx.NewId() for _init_ctrls in range(4)]
[ID_HELP_ABOUT, ID_HELP_CONTENT
] = [wx.NewId() for _init_ctrls in range(2)]

class TopFrame(AbstractFrame.AbstractFrame):


    def __createMenuBar(self):

        projectMenu = wx.Menu();
        projectMenu.Append(ID_NEW_PROJECT, "&New Project", "Create a new project")
        projectMenu.Append(ID_OPEN_PROJECT, "&Open Project", "Open an existing project")
        projectMenu.Append(ID_CLOSE_PROJECT, "&Close Project", "Close project that is currently opened")
        projectMenu.AppendSeparator()
        projectMenu.Append(ID_EXIT, "E&xit", "Exit the application");

        commandMenu = wx.Menu()
        commandMenu.Append(ID_CMD_CREATE, "&Create", "Create a new database")
        commandMenu.Append(ID_CMD_RECREATE, "&Recreate", "Drop and recreate an existing database")
        commandMenu.Append(ID_CMD_UPDATE, "&Update", "Update a database to a new version")
        commandMenu.Append(ID_CMD_PREPARE, "&Prepare", "Create a new alter tree")

        helpMenu = wx.Menu()
        helpMenu.Append(ID_HELP_ABOUT, "&About")
        helpMenu.Append(ID_HELP_CONTENT, "&Content")
        
        menuBar = wx.MenuBar()
        menuBar.Append(projectMenu, "&Project")
        menuBar.Append(commandMenu, "&Command")
        menuBar.Append(helpMenu, "&Help")
        
        self.SetMenuBar(menuBar)

        wx.EVT_MENU(self, ID_NEW_PROJECT, self.onNewProject)
        wx.EVT_MENU(self, ID_EXIT, self.onExit)
        wx.EVT_MENU(self, ID_HELP_ABOUT, self.onAbout)
        
    def __createStatusBar(self):
        self.__statusBar = self.CreateStatusBar();
        self.__statusBar.SetStatusText("To generate a new project, click on New Project in the Project menu, select a project directory and click on execute")


    def __init__(self, parent, title):

        AbstractFrame.AbstractFrame.__init__(self, parent, title)

        self.__createMenuBar()
        self.__createStatusBar()

    def onNewProject(self,event):
        dia = gui.ProjectDialog.ProjectDialog(self, ID_PROJECT_DLG, 'New Project', gui.ProjectDialog.DIALOG_TYPE_NEW)
        dia.ShowModal()
        dia.Destroy()


    def onExit(self, event):
        self.Close(True);
        
    def onAbout(self, event):
        dlg = wx.MessageDialog(self, 'Noora GUI v0.0.8.2', '(c) 2010', wx.OK|wx.ICON_INFORMATION)
        dlg.ShowModal()
        dlg.Destroy()





#!/usr/bin/env python

class ConnectorException(Exception):
    
  def __init__(self, message):
    Exception.__init__(self)
    self.__message=message

  def __str__(self):
    return repr(self.__message)

  def getMessage(self):
    return self.__message



import core.CommandDispatcher
import gui.LabelText
import gui.Project
import wx;

__revision__ = "$Revision: 79 $"

[wxID_ACTIONGROUP,
 wxID_COMMANDLABEL,
 wxID_COMMANDCHOICE,
 wxID_DATABASELABEL,
 wxID_DATABASETEXT,
 wxID_EXECUTE
] = [wx.NewId() for _init_ctrls in range(6)]

class Action:

    def _init_controls(self, parent):
        
        self.__parent = parent

        # not all wx implementations (e.g. wxGTK) will support children _inside_ the static box so
        # we make them siblings of the static box instead.

        self.actionGroup = wx.StaticBox(id=wxID_ACTIONGROUP, label='Action',
                                        name='action_group', parent=parent,
                                        pos=wx.Point(8, 128), size=wx.Size(320, 352),
                                        style=0)

        self.commandLabel = wx.StaticText(id=wxID_COMMANDLABEL, label='command',
              name='command', parent=parent, pos=wx.Point(20, 156),
              size=wx.Size(48, 13), style=0)

        self.commandChoice = wx.Choice(choices=['drop', 'clean', 'build', 'create', 'generate', 'recreate', 'update'],
                                 id=wxID_COMMANDCHOICE, name='command_choice', parent=parent,
                                 pos=wx.Point(88, 152), size=wx.Size(130, 25),
                                 style=0)

        self.database = gui.LabelText.LabelText(parent=parent, pos=wx.Point(20, 176),
                                                labelWidth=64, textWidth=100, label='database', value='')
        self.environment = gui.LabelText.LabelText(parent=parent, pos=wx.Point(20, 200),
                                                   labelWidth=64, textWidth=100, label='environment', value='')
        self.schema = gui.LabelText.LabelText(parent=parent, pos=wx.Point(20, 224),
                                              labelWidth=64, textWidth=100, label='schema', value='')

        self.execute = wx.Button(id=wxID_EXECUTE, label='execute',
              name='execute', parent=parent, pos=wx.Point(232, 440),
              size=wx.Size(75, 23), style=0)
        self.execute.Bind(wx.EVT_BUTTON, self.onExecute,
              id=wxID_EXECUTE)


    def onExecute(self, event):
        projectDir = self.__parent.projectGroup.projectDir.GetValue();
        command = self.commandChoice.GetStringSelection()
        self.__dispatcher = core.CommandDispatcher.CommandDispatcher(projectDir, command)

        arguments = []
        if command == 'generate':
            # get values for generate
            arguments.append(command);
            arguments.append('-si=' + self.database.text.GetValue())
            arguments.append('-sc=' + self.schema.text.GetValue())

        self.__dispatcher.setParameters(arguments)
        self.__dispatcher.execute()

    def __init__(self, parent):
        self._init_controls(parent)



import wx

class AbstractFrame(wx.Frame):
        
    def __init__(self, parent, title):
        
        if isinstance(parent,wx.Frame):        
            wx.Frame.__init__(self, parent, -1, title)
        else:
            wx.Frame.__init__(self,None,-1,title)
            


import wx
import AbstractPanel as AbstractPanel
import gui.Settings      as Settings

class CancelFinishPanel(AbstractPanel.AbstractPanel):

  def getCancelButton(self):
    return self.__cancelButton
  
  def getFinishButton(self):
    return self.__finishButton

  def __init__(self, parent, id):
    AbstractPanel.AbstractPanel.__init__(self, parent, id)
    
    sizer=wx.BoxSizer(wx.HORIZONTAL)        
    self.__cancelButton=wx.Button(self, Settings.ID_CANCEL,"Cancel") 
    self.__finishButton = wx.Button(self, Settings.ID_FINISH,"Finish")  
    sizer.Add(self.__cancelButton,0,wx.EXPAND)
    sizer.Add(self.__finishButton,0,wx.EXPAND)
    self.SetSizer(sizer)    
    self.Layout()



import wx
import Settings as Settings

class MainMenuBar(wx.MenuBar):

    def __init__(self):        
        wx.MenuBar.__init__(self)
        menu = wx.Menu()
        menu.Append(Settings.ID_NEW_PROJECT, "&New Project\tAlt-N", "Create a new project")
        menu.Append(Settings.ID_OPEN_PROJECT, "&Open Project\tAlt-O", "Open an existing project")      
        menu.AppendSeparator()
        menu.Append(wx.ID_EXIT, "E&xit", "Exit the application");
        self.Append(menu, "&File")

        menu = wx.Menu()
        menu.Append(Settings.ID_EDIT_PROJECT, "&project.conf...\tAlt-p","View the project configuration file")
        self.Append(menu, "&View")  
        
        menu = wx.Menu()
        showViewMenu = wx.Menu()
        showViewMenu.Append(Settings.ID_SHOW_ACTION_VIEW, "&Action\tAlt-a","Show the action view")
        showViewMenu.Append(Settings.ID_SHOW_CONSOLE_VIEW, "&Console\tAlt-c","Show the console view")
        menu.AppendSubMenu(showViewMenu, "Show View")
        self.Append(menu, "&Window")        
        
        
        
        menu = wx.Menu()
        menu.Append(wx.ID_ABOUT, "&About\tAlt-A","About")
        self.Append(menu, "&Help")
        


#!/usr/bin/env python

import sys
import os
import core.ConfigReader    as ConfigReader
import core.PluginManager   as PluginManager
import core.ParameterHelper as ParameterHelper
import core.NooraException  as NooraException
import core.ClassLoader     as ClassLoader
import logging.handlers

__revision__ = "$Revision: 290 $"
__version__  = "0.0.8.2"

NOORA_DIR    = os.path.abspath(os.path.dirname(sys.argv[0]))
BASE_DIR     = os.path.abspath('.')
PLUGIN_DIR   = NOORA_DIR+os.sep+'plugins'
sys.path.append(PLUGIN_DIR)



def getRevision():  
  print "noora version " + __version__  + "_" + __revision__.split(":")[1].rstrip("$")
  
  

def findTemplateFile(filename):
  url=BASE_DIR+os.sep+filename
  if os.path.isfile(url):
    return url
  url=NOORA_DIR+os.sep+filename
  if os.path.isfile(url):
    return url
  return None

def failOnPluginNotFound(message):
  raise NooraException.NooraException(message)


if __name__ == "__main__":

  try:
    
    logger = logging.getLogger('NoOraLogger')
    handler = logging.handlers.RotatingFileHandler('noora.log')
    formatter = logging.Formatter('%(asctime)s %(levelname)s %(message)s')
    handler.setFormatter(formatter)
    logger.addHandler(handler)         
    handler.doRollover()        
    logger.setLevel(logging.ERROR)
    
    
    parameterHelper=ParameterHelper.ParameterHelper()      
    if parameterHelper.hasParameter('-r'):
      getRevision()
      exit(1)
 
    config = ConfigReader.ConfigReader(findTemplateFile('project.conf'))
    
    classLoader = ClassLoader.ClassLoader()
    pluginManager = PluginManager.PluginManager()

    config.failOnConfigNotLoaded()


    parameters=parameterHelper.getParameters()

    plugins = config.getValue('PLUGINS')
    for plugin in plugins:
      pluginClass=classLoader.findByPattern(plugin)
      pluginManager.registerPlugin(pluginClass)
    
        
    for plugin in pluginManager.getPlugins():
      
      for parameter in parameters:
        if parameter.upper() == plugin.getType():
          plugin.execute(parameterHelper)
          exit(0)

    failOnPluginNotFound('no plugin found.')
    
  
  except NooraException.NooraException as e:
    print e.getMessage()
    exit(1)
  



import wx
import AbstractPanel        as AbstractPanel
import gui.panels.ComboBoxPanel as ComboBoxPanel
import gui.panels.TextPanel     as TextPanel
import gui.Settings             as Settings

class ActionPanel(AbstractPanel.AbstractPanel):

  def getDesciptionControl(self):
    return self.__descriptionControl

  def getCommandControl(self):
    return self.__commandControl
  
  def getDatabaseControl(self):
    return self.__databaseControl

  def getSchemeControl(self):
    return self.__schemeControl

  def getEnvironmentControl(self):
    return self.__environmentControl
  
  def getVersionControl(self):
    return self.__versionControl

  def __init__(self, parent, id):
    AbstractPanel.AbstractPanel.__init__(self, parent, id)
    
    sizer=wx.BoxSizer(wx.VERTICAL)
    self.__descriptionControl=wx.StaticText(self, -1, "")        
    self.__commandControl=ComboBoxPanel.ComboBoxPanel(self,Settings.ID_COMMAND,"Command",[])
    self.__commandControl.Enable(False)
    self.__databaseControl = ComboBoxPanel.ComboBoxPanel(self,-1,"Database",[])
    self.__databaseControl.Enable(False)
    self.__schemeControl = ComboBoxPanel.ComboBoxPanel(self,-1,"Scheme",[])
    self.__schemeControl.Enable(False)
    self.__environmentControl = ComboBoxPanel.ComboBoxPanel(self,-1,"Environment",[])
    self.__environmentControl.Enable(False)
    self.__versionControl = ComboBoxPanel.ComboBoxPanel(self,-1,"Version",[])
    self.__versionControl.Enable(False)
    
    sizer.Add(self.__descriptionControl,0,wx.ALL,5)
    sizer.Add(self.__commandControl,0,wx.ALL,5)
    sizer.Add(self.__databaseControl,0,wx.ALL,5)
    sizer.Add(self.__schemeControl,0,wx.ALL,5)
    sizer.Add(self.__environmentControl,0,wx.ALL,5)
    sizer.Add(self.__versionControl,0,wx.ALL,5)
    self.SetSizer(sizer)    



#!/usr/bin/env python

class UnrecognizedArgumentException(Exception):
    
  def __init__(self, message, unrecognizedArgument):
    Exception.__init__(self)            
    self.__unrecognizedArgument=unrecognizedArgument    
    message = message + " " + unrecognizedArgument 
    self.__message=message  

  def __str__(self):
    return repr(self.__message)

  def getMessage(self):
    return self.__message
  
  def getUnrecognizedArgument(self):
    return self.__unrecognizedArgument



#!/usr/bin/env python
import os
from org.noora.plugin.Plugin import Plugin
from org.noora.helper.PropertyHelper import PropertyHelper
from org.noora.io.File import File
from org.noora.cl.OptionFactory import OptionFactory
from org.noora.plugin.ConnectionExecutor import ConnectionExecutor
from org.noora.connector.ExecuteFactory import ExecuteFactory
from org.noora.connector.ConnectorFactory import ConnectorFactory



class CreatePlugin(Plugin):
  
  __revision__ = "$Revision: 249 $"
  
  def __init__(self):
    Plugin.__init__(self, "CREATE", ConnectorFactory.newMysqlConnector())
    
  def getDescription(self):
    return "executes the defined baseline scripts in the create folder."
  
  def getCreateDir(self):
    return os.path.abspath('.')+os.sep+'create'

  def getOptions(self, properties):
    options = Plugin.getOptions(self)
    options.addOption("-?", "--help", False, False,  "display help")
    
    option = OptionFactory.newOption("-h", "--host", True, True, "hostname of the mysql-server.")
    option.setValues(properties.getPropertyValues('MYSQL_HOSTS'))
    options.add(option)
    
    option = OptionFactory.newOption("-d", "--database", True, False, "database in the mysql-server.")
    option.setValues(properties.getPropertyValues('DATABASES'))
    options.add(option)
    
    option = OptionFactory.newOption("-e", "--environment", True, False, "environment descriptor of the mysql-server.")
    option.setValues(properties.getPropertyValues('ENVIRONMENTS'))
    options.add(option)
    
    options.addOption("-i", "--ignore-errors", True, False, "ignore errors.")          
    return options

  def execute(self, commandLine, properties):
    ignoreErrors = commandLine.getOptionValue('--ignore-errors', False)
   
    host = commandLine.getOptionValue('-h')  
    defaultDatabases = properties.getPropertyValues('DATABASES')
    databases = commandLine.getOptionValues('-d', defaultDatabases)
    defaultEnvironment = properties.getProperty('DEFAULT_ENVIRONMENT')
    environment = commandLine.getOptionValue('-e', defaultEnvironment)
    objects = properties.getPropertyValues('CREATE_OBJECTS')
    
    connector = self.getConnector()    

    for database in databases:
      print "creating database '"+database+"' on host '"+host+"' using environment '"+environment+"'"
      
      users= properties.getPropertyValues('MYSQL_USERS')
      user = PropertyHelper.getMysqlUser(users, host, database)
      passwd = PropertyHelper.getMysqlPasswd(users, host, database)

      executor = ExecuteFactory.newMysqlExecute()
      executor.setHost(host)
      executor.setDatabase(database)
      executor.setIgnoreErrors(ignoreErrors)
      executor.setPassword(passwd)
      executor.setUsername(user)        
      
      for object in objects:  

        # global ddl objects
        folder=File(self.getCreateDir()+os.sep+database+os.sep+'ddl'+os.sep+object)
        ConnectionExecutor.execute(connector, executor, properties, folder)

        # environment specific ddl objects
        folder=File(self.getCreateDir()+os.sep+database+os.sep+'ddl'+os.sep+object+os.sep+environment)
        ConnectionExecutor.execute(connector, executor, properties, folder)

      # global dat objects
      folder=File(self.getCreateDir()+os.sep+database+os.sep+'dat')
      ConnectionExecutor.execute(connector, executor, properties, folder)

      # environment specific dat objects
      folder=File(self.getCreateDir()+os.sep+database+os.sep+'dat'+os.sep+environment)
      ConnectionExecutor.execute(connector, executor, properties, folder)

      print "database '"+database+"' created."





#!/usr/bin/env python


class VersionHelper:

  def __init__(self, versions):
    self.__versions=self.getWeightList(versions)

  def getVersions(self):
    return self.__versions

  def getMajorPart(self, value):
    return int(value.split('.')[0])

  def getMinorPart(self, value):
    return int(value.split('.')[1])

  def getRevisionPart(self, value):
    return int(value.split('.')[2])

  def getNextRevision(self, default):
    versions=self.getVersions()
    versions.sort()
    if len(versions)!=0:
      lastVersion=versions[len(versions)-1][1]
      majorPart=self.getMajorPart(lastVersion)
      minorPart=self.getMinorPart(lastVersion)
      revisionPart=self.getRevisionPart(lastVersion)
      return str(majorPart)+'.'+str(minorPart)+'.'+str(revisionPart+1)
    return default

  def getWeightList(self, versions):
    items=[]
    for version in versions:
      majorPart=self.getMajorPart(version)
      minorPart=self.getMinorPart(version)
      revisionPart=self.getRevisionPart(version)
      items.append([(10*revisionPart)+(1000*minorPart)+(10000*majorPart),version])
    return items

  def sort(self):
    items=[]
    versions=self.getVersions()
    versions.sort()
    for version in versions:
      items.append(version[1])
    return items





#!/usr/bin/env python

from org.noora.cl.Options import Options

class CommandLine:
  
  def __init__(self):
    self.__options=Options()
    
  def addOption(self, option):
    self.__options.add(option)    
    
  def hasOption(self, type):
    options = self.__options
    return options.hasOption(type)

  def getOptionValues(self, type, defaultValue=None):
    options = self.getOptions()
    if options.hasOption(type):
      option = options.getOption(type)
      return option.getValues()
    return defaultValue
  
  def getOptionValue(self, type, defaultValue=None):
    options = self.getOptions()
    if options.hasOption(type):
      option = options.getOption(type)
      return option.getValue()
    return defaultValue
  
  def getRequiredArguments(self):
    options = self.getOptions()
    return options.getRequiredArguments() 
      
  def getOptions(self):
    return self.__options
  
  




#!/usr/bin/env python

import core.Plugin as Plugin
import os


class UpdatePlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("UPDATE")


  def getUsage(self):  
    print "Noora database installer, update.py"
    print "executes the defined update scripts in the alter folders."
    print "-s= --sid=     required, contains the tnsname of the database."
    print "-v= --version= required, contains the version of the update"
    print "                         to execute"
    print "-u= --scheme=  not required, contains the scheme of "
    print "               the database objects to drop."
    print "-e= --env=     not required, used for mapping "
    print "               the username and password."
    print "-nocompile     not required, disable the compilation of "
    print "               packages, triggers and views."

  def getPluginDir(self):
    return self.getNooraDir()+os.sep+'plugins'+os.sep+'static'+os.sep+'update'

  def getPreviousVersion(self, version):
    configReader=self.getConfigReader()
    versions=configReader.getValue('VERSIONS')

    index=versions.index(version)
    if index>0:
      previousVersion=versions[index-1]
      return previousVersion    
    return None


  def checkVersion(self, oracleSid,oracleUser,oraclePasswd,previousVersion, versionSelectStatement,ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getPluginDir()+os.sep+'checkversion.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,previousVersion,versionSelectStatement,ignoreErrors)


  def checkEnvironment(self, oracleSid,oracleUser,oraclePasswd, environment, environmentSelectStatement,ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getPluginDir()+os.sep+'checkenvironment.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,environment,environmentSelectStatement,ignoreErrors)
 

  def recompile(self, oracleSid, oracleUser, oraclePasswd,ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getPluginDir()+os.sep+'recompile.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,'', '',ignoreErrors)


  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    

    ignoreErrors=False  
    if  parameterHelper.hasParameter('-ignore_errors')==True:
      ignoreErrors=True      


    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()

    oracleSid=parameterHelper.getParameterValue(['-s=','--sid='],[])
    projectHelper.failOnEmpty(oracleSid,'no oracle sid was given.')
    configReader.failOnValueNotFound('ORACLE_SIDS',oracleSid,'the given oracle sid is not valid for this project.')
    oracleSid=oracleSid[0]
    
    schemes=configReader.getValue('SCHEMES')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    environment=configReader.getValue('DEFAULT_ENVIRONMENT')
    environment=parameterHelper.getParameterValue(['-e=','--env='],[environment])
    projectHelper.failOnEmpty(environment,'no environment was found')
    configReader.failOnValueNotFound('ENVIRONMENTS',environment,'the given environment is not valid for this project.')
    environment=environment[0]


    version=parameterHelper.getParameterValue(['-v=','--version='],[])
    projectHelper.failOnEmpty(version,'no version was given')
    configReader.failOnValueNotFound('VERSIONS',version,'the given version is not valid for this project.')
    version=version[0]
    projectHelper.failOnFolderNotPresent(self.getAlterDir()+os.sep+version,'the update folder for this version is not present.')

    previousVersion=self.getPreviousVersion(version)
    projectHelper.failOnNone(previousVersion,'the previous version of this version could not be found.')

    versionScheme=configReader.getValue('VERSION_SCHEME')
    projectHelper.failOnNone(previousVersion,'the variable VERSION_SCHEME is not set.')
    oracleUser=projectHelper.getOracleUser(oracleSid, versionScheme)
    oraclePasswd=projectHelper.getOraclePasswd(oracleSid, versionScheme)

    versionSelectStatement=configReader.getValue('VERSION_SELECT_STATEMENT')
    projectHelper.failOnNone(versionSelectStatement,'the variable VERSION_SELECT_STATEMENT is not set.')
    environmentSelectStatement=configReader.getValue('ENVIRONMENT_SELECT_STATEMENT')
    projectHelper.failOnNone(versionSelectStatement,'the variable ENVIRONMENT_SELECT_STATEMENT is not set.')
    self.checkVersion(oracleSid,oracleUser,oraclePasswd,previousVersion,versionSelectStatement,ignoreErrors)
    self.checkEnvironment(oracleSid,oracleUser,oraclePasswd,environment,environmentSelectStatement,ignoreErrors)

    connector=self.getConnector()

    for scheme in schemes:

      print "updating scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
      oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
      oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)

      url=self.getAlterDir()+os.sep+version+os.sep+scheme+os.sep+'install_scheme_'+environment+'.sql'
      projectHelper.failOnFileNotPresent(url,scheme+os.sep+'install_scheme_'+environment+'.sql not found, try to build this scheme.')
      connector.execute(oracleSid, oracleUser, oraclePasswd, url,'','',ignoreErrors)
   
      print "scheme '"+scheme+"' updated."

    if  parameterHelper.hasParameter('-nocompile')==False:
      for scheme in schemes:
        print "compiling scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
        oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
        oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
        self.recompile(oracleSid,oracleUser,oraclePasswd, ignoreErrors)
        print "scheme '"+scheme+"' compiled."





#!/usr/bin/env python

from org.noora.plugin.Pluginable import Pluginable
from org.noora.cl.Options import Options
import logging



class Plugin(Pluginable):
  
  logger = logging.getLogger("NoOraLogger")
  __revision__ = "$Revision: 245 $"
  
  def __init__(self, type, connectable):
    Pluginable.__init__(self, type, connectable)
    self.__options = Options()
    self.setType(type)
    self.setConnector(connectable)    

  def setConnector(self, connectable):
    self.__connectable=connectable

  def getConnector(self):
    return self.__connectable
    
  def setExecutor(self, executable):
    self.__executable=executable

  def getExecutor(self):
    return self.__executable

  def setType(self, type):
    self.__type = type

  def getType(self):
    return self.__type

  def getRevision(self):
    return self.__revision__

  def getOptions(self):
    return self.__options
  

    



#!/usr/bin/env python
from org.noora.io.Readable import Readable
from xml.etree.ElementTree import ElementTree



class XmlFileReader(Readable):
  def __init__(self, file=None):
    Readable.__init__(self)
    self.__file = file
    pathName = file.getPath() + file.getName()
    self.__handle = ElementTree()

    
    
    
  def read(self):
    handle = self.__handle
    file = self.__file
    handle.parse(file.getPath()+file.getName())    
    return handle
  
  def getFile(self):
    return self.__file
    
  def close(self):
    pass
    

       





#!/usr/bin/env python
import os
from org.noora.plugin.Plugin import Plugin
from org.noora.helper.PropertyHelper import PropertyHelper
from org.noora.io.File import File
from org.noora.cl.OptionFactory import OptionFactory
from org.noora.plugin.ConnectionExecutor import ConnectionExecutor
from org.noora.connector.ExecuteFactory import ExecuteFactory
from org.noora.connector.ConnectorFactory import ConnectorFactory
from org.noora.plugin.mysql.update.UnknownVersionException import UnknownVersionException
from org.noora.plugin.mysql.update.InvalidEnvironmentException import InvalidEnvironmentException

class UpdatePlugin(Plugin):
  
  __revision__ = "$Revision: 249 $"
  
  def __init__(self):
    Plugin.__init__(self, "UPDATE", ConnectorFactory.newMysqlConnector())
    
  def getDescription(self):
    return "install the given update part of a database project in the database."
  
  def getAlterDir(self):
    return os.path.abspath('.')+os.sep+'alter'

  def getOptions(self, properties):
    options = Plugin.getOptions(self)
    options.addOption("-?", "--help", False, False,  "display help")
    
    option = OptionFactory.newOption("-h", "--host", True, True, "hostname of the mysql-server.")
    option.setValues(properties.getPropertyValues('MYSQL_HOSTS'))
    options.add(option)
    
    option = OptionFactory.newOption("-d", "--database", True, False, "database in the mysql-server.")
    option.setValues(properties.getPropertyValues('DATABASES'))
    options.add(option)
    
    option = OptionFactory.newOption("-e", "--environment", True, False, "environment descriptor of the mysql-server.")
    option.setValues(properties.getPropertyValues('ENVIRONMENTS'))
    options.add(option)
    
    option = OptionFactory.newOption("-v", "--version", True, True, "version folder to install.")
    #option.setValues(properties.getPropertyValues('ENVIRONMENTS'))
    options.add(option)
    
    
    options.addOption("-i", "--ignore-errors", True, False, "ignore errors.")          
    return options
  
  def checkVersionFolder(self, version, properties):
    versionFolder = File(self.getAlterDir()+os.sep+version)
    if versionFolder.notExists():
      raise UnknownVersionException("unknown version folder", version)

  def checkEnvironment(self, connector, executor, environment, properties):
    pluginFolder = properties.getPropertyValue('plugin.dir')
    properties.setProperty('environment',environment)
    script = File(pluginFolder+os.sep+'mysql'+os.sep+'update'+os.sep+'checkenvironment.sql')
    executor.setScript(script)      
    connector.execute(executor, properties)
    if "(Code 1329)" in connector.getProcessorResult().getResult():
      raise InvalidEnvironmentException("invalid environment",environment) 



  def execute(self, commandLine, properties):
    ignoreErrors = commandLine.getOptionValue('--ignore-errors', False)
   
    host = commandLine.getOptionValue('-h')  
    version = commandLine.getOptionValue('-v')
    
    
    
    defaultDatabases = properties.getPropertyValues('DATABASES')
    databases = commandLine.getOptionValues('-d', defaultDatabases)
    defaultEnvironment = properties.getProperty('DEFAULT_ENVIRONMENT')
    environment = commandLine.getOptionValue('-e', defaultEnvironment)
    objects = properties.getPropertyValues('CREATE_OBJECTS')
    
    self.checkVersionFolder(version, properties)
    
    
    connector = self.getConnector()    

    for database in databases:
      print "updating database '"+database+"' on host '"+host+"' using environment '"+environment+"'"
      
      users= properties.getPropertyValues('MYSQL_USERS')
      user = PropertyHelper.getMysqlUser(users, host, database)
      passwd = PropertyHelper.getMysqlPasswd(users, host, database)

      executor = ExecuteFactory.newMysqlExecute()
      executor.setHost(host)
      executor.setDatabase(database)
      executor.setIgnoreErrors(ignoreErrors)
      executor.setPassword(passwd)
      executor.setUsername(user)        
      
      self.checkEnvironment(connector, executor, environment, properties)
      
      for object in objects:  

        # global ddl objects
        folder=File(self.getAlterDir()+os.sep+version+os.sep+database+os.sep+'ddl'+os.sep+object)
        ConnectionExecutor.execute(connector, executor, properties, folder)

        # environment specific ddl objects
        folder=File(self.getAlterDir()+os.sep+version+os.sep+database+os.sep+'ddl'+os.sep+object+os.sep+environment)
        ConnectionExecutor.execute(connector, executor, properties, folder)

      # global dat objects
      folder=File(self.getAlterDir()+os.sep+version+os.sep+database+os.sep+'dat')
      ConnectionExecutor.execute(connector, executor, properties, folder)

      # environment specific dat objects
      folder=File(self.getAlterDir()+os.sep+version+os.sep+database+os.sep+'dat'+os.sep+environment)
      ConnectionExecutor.execute(connector, executor, properties, folder)

      print "database '"+database+"' updated."





#!/usr/bin/env python
from org.noora.io.Writeable import Writeable

class FileWriter(Writeable):
  def __init__(self, file=None):
    Writeable.__init__(self)
    self.__file = file
    pathName = file.getPath() + file.getName()            
    self.__handle = open(pathName,'wb')

  def getFile(self):
    return self.__file
    
  def fileno(self):
    handle = self.__handle
    return handle.fileno()    
    
  def write(self, buffer):
    handle = self.__handle
    handle.write(buffer)
    
  def close(self):
    handle = self.__handle
    handle.close()
    
    

       





#!/usr/bin/env python

from org.noora.parser.PreProcessable import PreProcessable

class PreProcessor(PreProcessable):
  def __init__(self):
    PreProcessable.__init__(self)
  
  def parse(self, parsable=None):
    return parsable.parse()




#!/usr/bin/env python
from org.noora.parser.Parsable import Parsable

class Parser(Parsable):
  def __init__(self, readable=None, properties=None):
    Parsable.__init__(self)
    self.__readable = readable
    self.__properties = properties
    
  def getReadable(self):
    return self.__readable
  
  def getProperties(self):
    return self.__properties    
  
  def parse(self):
    readable = self.getReadable()
    properties = self.getProperties()
    
    stream= readable.read()    
    for property in properties.list():
      if property.getValue():
        stream = stream.replace("{" + property.getKey() + "}",property.getValue())    
    return stream
    




#!/usr/bin/env python
import StreamHelper as StreamHelper
import NooraException as NooraException
M_LF = chr(10)

class ConfigReader:
    
  def __init__(self, filename):    
    self.__lines=[]
    self.__message=None
    self.loadFromFile(filename)
   
  def parse(self, stream):
    stream = StreamHelper.StreamHelper().convert(stream)
    lines = stream.split(chr(10))
    for line in lines:
      self.__lines.append(line)
    
  def loadFromFile(self, filename):
    try:
      handle=open(filename,'r')
      stream=handle.read()
      handle.close()
      self.parse(stream)
    except IOError:
      self.setMessage('project configuration file "' + filename + '" not found.')

  def saveToFile(self, filename):
    stream=M_LF.join(self.__lines)
    handle=open(filename,'w')
    handle.write(stream)
    handle.close()
      
  def getValue(self,keyword):
    lines=self.__lines
    for line in lines:
      if line.startswith(keyword):
        values=line.split('=')[1::]
        value='='.join(values)
        return eval(value)
    return None

  def setValue(self,keyword,value):
    lines=self.__lines
    for line in lines:
      if line.startswith(keyword):
        newLine=keyword+'='+str(value)
        lines[lines.index(line)] = newLine


  def hasValue(self, keyword, value):
    values=self.getValue(keyword)
    for val in values:
      if val.lower()==value.lower():
        return True
    return False

  def failOnValueNotFound(self, keyword, values, message):
    for value in values:
      if self.hasValue(keyword, value)==False:
        raise NooraException.NooraException(message)

  def failOnValueFound(self, keyword, values, message):
    for value in values:
      if self.hasValue(keyword, value)==True:
        raise NooraException.NooraException(message)

  def failOnConfigNotLoaded(self):
    if self.getMessage()!=None:
      print self.getMessage()
      exit(1)
        

  def setMessage(self, message):
    self.__message=message

  def getMessage(self):
    return self.__message








#!/usr/bin/env python
from org.noora.cl.ParseException import ParseException

class Parseable:
  def __init__(self):
    pass
  
  def checkRequiredOptions(self):
    raise ParseException("method not implemented")
    
  def parse(self, options=None, arguments=None): 
    raise ParseException("method not implemented")


#!/usr/bin/env python

from org.noora.parser.ParserException import ParserException

class Parsable():
  def __init__(self):
    pass
    
  def parse(self):
    raise ParserException("method not implemented")
 



#!/usr/bin/env python
from org.noora.io.IOException import IOException

class Filterable:
  def __init__(self):
    pass
    
  def accept(self, fileable):
    raise IOException("method not implemented")
       





#!/usr/bin/env python

import core.ProjectHelper         as ProjectHelper
import core.ConfigReader          as ConfigReader
import core.ParameterDefinition   as ParameterDefinition
import connectors.OracleConnector as OracleConnector
import os
import sys

__revision__ = "$Revision: $"

class Plugin:

  def __init__(self):
    configReader=ConfigReader.ConfigReader('project.conf')
    self.setConfigReader(configReader)
    self.setProjectHelper(ProjectHelper.ProjectHelper(configReader))
    self.setConnector(OracleConnector.OracleConnector())
    self.setNooraDir(os.path.abspath(os.path.dirname(sys.argv[0])))
    self.setBaseDir(os.path.abspath('.'))
    self.__parameterDefinitions=[]

  def setNooraDir(self, path):
    self.__nooraDir=path
    
  def getNooraDir(self):
    return self.__nooraDir
  
  def setBaseDir(self, path):
    self.__baseDir=path
    
  def getBaseDir(self):
    return self.__baseDir
  
  def getScriptDir(self):
    return self.getNooraDir()+os.sep+'scripts'
  
  def getAlterDir(self):
    return self.getBaseDir()+os.sep+'alter'

  def setConfigReader(self, configReader):
    self.__configReader=configReader

  def getConfigReader(self):
    return self.__configReader
  
  def setProjectHelper(self, projectHelper):
    self.__projectHelper=projectHelper

  def getProjectHelper(self):
    return self.__projectHelper

  def setConnector(self, connector):
    self.__connector=connector

  def getConnector(self):
    return self.__connector

  def getUsage(self):
    pass
  
  def getDescription(self):
    return ""

  def setType(self, type):
    self.__type = type

  def getType(self):
    return self.__type

  def getRevision(self):
    return self.__revision__

  def execute(self, parameters):
    pass
  
  def getParameterDefinitions(self):
    return self.__parameterDefinitions
  
  def addParameterDefinition(self, key, parameters):
    parameterDefinition=ParameterDefinition.ParameterDefinition(key,parameters)
    parameterDefinition.setKey(key)
    parameterDefinition.setParameters(parameters)
    
    parameterDefinitions=self.getParameterDefinitions()
    parameterDefinitions.append(parameterDefinition)
    
  def findParameterDefinition(self, key):
    parameterDefinitions=self.getParameterDefinitions()
    for parameterDefinition in parameterDefinitions:
      if parameterDefinition.getKey().lower()==key.lower():
        return parameterDefinition
    return None
    



#!/usr/bin/env python

class PropertyHelper:

  def __init__(self):
    pass
  
  @staticmethod
  def getUser(users, host, database):
    for user in users:
      if user[0].lower() == host.lower() and user[1].lower() == database.lower():
        return user[2]
    return None
  
  @staticmethod
  def getPasswd(users, host, database):
    for user in users:
      if user[0].lower() == host.lower() and user[1].lower() == database.lower():
        return user[3]
    return None

  

  @staticmethod
  def getMysqlUser(users, host, database):
    for user in users:
      if user[0].lower() == host.lower() and user[1].lower() == database.lower():
        return user[2]
    return None
  
  @staticmethod
  def getMysqlPasswd(users, host, database):
    for user in users:
      if user[0].lower() == host.lower() and user[1].lower() == database.lower():
        return user[3]
    return None

  @staticmethod
  def getOracleUser(users, sid, scheme):
    for user in users:
      if user[0].lower() == sid.lower() and user[1].lower() == scheme.lower():
        return user[2]
    return None
  
  @staticmethod
  def getOraclePasswd(users, sid, scheme):
    for user in users:
      if user[0].lower() == sid.lower() and user[1].lower() == scheme.lower():
        return user[3]
    return None




#!/usr/bin/env python
from org.noora.io.Property import Property
  
class Properties:

  def __init__(self):
    self.__properties = []

  def clear(self):
    self.__properties = []

  def containsProperty(self, key):
    result = True
    property = self.getProperty(key)
    if property == None:
      result = False
    return result
    
  def setProperty(self, key, value):
    properties = self.__properties
    if self.containsProperty(key):
      property = self.getProperty(key)
      properties.remove(property)          
    property = Property(key, value)
    properties.append(property)
    return property

  def size(self):
    properties=self.__properties
    return len(properties)
  
  def list(self):
    return self.__properties
  
  def getProperty(self, key):
    result = None
    properties = self.__properties
    for property in properties:
      if property.getKey() == key:
        result = property
    return result
       
  def getPropertyValue(self, key, defaultValue=None):
    result = defaultValue
    properties = self.__properties
    for property in properties:
      if property.getKey() == key:
        result = property.getValue()
    return result
  
  def getPropertyValues(self, key):
    return eval(self.getPropertyValue(key))





#!/usr/bin/env python
from org.noora.cl.Parseable import Parseable
from org.noora.cl.CommandLine import CommandLine
from org.noora.cl.MissingOptionException import MissingOptionException
from org.noora.cl.MissingArgumentException import MissingArgumentException
from org.noora.cl.UnrecognizedOptionException import UnrecognizedOptionException
from org.noora.cl.UnrecognizedArgumentException import UnrecognizedArgumentException

class Parser(Parseable):
  def __init__(self):
    Parseable.__init__(self)
    self.__options = None
    self.__commandLine = None
    
  def checkRequiredOptions(self):    
    options=self.__options
    commandLineList=self.__commandLine.getOptions().getOptions()    
    missingOptions = []
    
    for option in options.getRequiredOptions():
      if option not in commandLineList:
        missingOptions.append(option) 
      
    if missingOptions:   
      raise MissingOptionException('missing option',missingOptions)

  def checkUnrecognizedOptions(self):    
    options=self.__options
    commandLineList=self.__commandLine.getOptions().getOptions()    
    missingOptions = []
    
    for option in options.getRequiredOptions():
      if option not in commandLineList:
        missingOptions.append(option) 
      
    if missingOptions:   
      raise MissingOptionException('missing option',missingOptions)

    
  def checkRequiredArguments(self):
    
    missingArguments = self.__commandLine.getRequiredArguments()
    if missingArguments:
      raise MissingArgumentException('missing argument in option',missingArguments)
    
      
  def parse(self, options=None, arguments=None, stopAtNonRecognizedOption=False):
    self.__options = options
    self.__arguments = arguments
    self.__commandLine = CommandLine()
    for argument in arguments:      
      values = argument.split('=')
      if options.hasOption(values[0])==True:          
          option = options.getOption(values[0])  
          
          if option.hasValues():
            for argumentValue in values[1:]:
              if argumentValue not in option.getValues():
                raise UnrecognizedArgumentException("unrecognized argument",argumentValue)
        
          if values[1:]!=['']:        
            option.setValues(values[1:])
          self.__commandLine.addOption(option)
      else:
        if stopAtNonRecognizedOption:
          raise UnrecognizedOptionException('unrecognized option',values[0])
          
        
    return self.__commandLine


#!/usr/bin/env python
from org.noora.version.Version import Version

class VersionFactory:
  def __init__(self):
    pass
  
  @staticmethod
  def newVersion(major=None, minor=None, revision=None, patch=None):
    return Version(major, minor, revision, patch)



#!/usr/bin/env python

import core.Plugin as Plugin
import os
import subprocess
import core.NooraException as NooraException
from connectors.SqlLoaderConnector import SqlLoaderConnector
from connectors.LoadJavaConnector import LoadJavaConnector

class CreatePlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setSqlLoaderConnector(SqlLoaderConnector())
    self.setLoadJavaConnector(LoadJavaConnector())
    self.setType("CREATE")
    
    self.addParameterDefinition('database',['-s','-si','--sid'])
    self.addParameterDefinition('scheme',['-u','-sc','--scheme'])
    self.addParameterDefinition('environment',['-e','--env'])
    
  def setSqlLoaderConnector(self, connector):
    self.__sqlLoaderConnector = connector
  
  def getSqlLoaderConnector(self):
    return self.__sqlLoaderConnector
  
  def setLoadJavaConnector(self, connector):
    self.__loadJavaConnector = connector
    
  def getLoadJavaConnector(self):
    return self.__loadJavaConnector

  def getDescription(self):
    return "executes the defined baseline scripts in the create folder."

  def getUsage(self):  
    print "NoOra database installer, create.py"
    print self.getDescription()
    print "-s= --sid=     required contains the tnsname of the database."
    print "-u= --scheme=  not required, contains the scheme of "
    print "               the database objects to drop."
    print "-e= --env=     not required, used for mapping "
    print "               the username and password."
    print "-nocompile     not required, disable the compilation of "
    print "               packages, triggers and views."

  
  def getCreateDir(self):
    return self.getBaseDir()+os.sep+'create'


  def installComponent(self, url, oracleSid, oracleUser, oraclePasswd):
    projectHelper=self.getProjectHelper()
    handle=open('feedback.log','wb')
    result=subprocess.call(['python',url+os.sep+'setup.py','-s='+oracleSid,'-u='+oracleUser,'-p='+oraclePasswd,'-silent'],shell=False,stdout=handle,stderr=handle)
    if result!=0:
      stream=projectHelper.readFile('feedback.log')
      raise NooraException.NooraException(stream)


  def installFiles(self, folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors):
    connector=self.getConnector()
    projectHelper=self.getProjectHelper()
    files=projectHelper.findFiles(folder)
    for file in files:
      url=folder+os.sep+file
      print url.split(self.getBaseDir())[1]
      if projectHelper.getFileExtension(file).lower()=='zip':
        projectHelper.extractFile(url)
        extractFolder=projectHelper.getFileRoot(url)
        self.installComponent(extractFolder,oracleSid,oracleUser,oraclePasswd)
        projectHelper.removeFolderRecursive(extractFolder)
      elif projectHelper.getFileExtension(file).lower()=='mdl':
        pass
      elif projectHelper.getFileExtension(file).lower()=='jar':
        loadJavaConnector = self.getLoadJavaConnector()
        loadJavaConnector.execute(oracleSid, oracleUser, oraclePasswd, url, '', '', ignoreErrors)  
      else:
        connector.execute(oracleSid, oracleUser, oraclePasswd, url, '', '', ignoreErrors)  


  def loadFiles(self, folder, oracleSid, oracleUser, oraclePasswd, ctlFile, ignoreErrors):   
    connector=self.getSqlLoaderConnector()
    projectHelper=self.getProjectHelper() 
    files=projectHelper.findFiles(folder)
    for file in files:
      url=folder+os.sep+file
      print url.split(self.getBaseDir())[1]
      if projectHelper.getFileExtension(file).lower()=='zip':
        projectHelper.extractFile(url,projectHelper.getFileRoot(file))
        
        for extractedFile in projectHelper.findFiles(folder+os.sep+projectHelper.getFileRoot(file)):
          connector.execute(oracleSid, oracleUser, oraclePasswd, ctlFile, extractedFile, ignoreErrors)
        projectHelper.removeFolderRecursive(folder+os.sep+projectHelper.getFileRoot(file))
      elif projectHelper.getFileExtension(file).lower()=='mdl':
        pass
      elif projectHelper.getFileExtension(file).lower()=='jar':
        loadJavaConnector = self.getLoadJavaConnector()
        loadJavaConnector.execute(oracleSid, oracleUser, oraclePasswd, url, '', '', ignoreErrors)        
      else:
        connector.execute(oracleSid, oracleUser, oraclePasswd, ctlFile, folder + os.sep + file, ignoreErrors)  



  def recompile(self, oracleSid, oracleUser, oraclePasswd, ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getScriptDir()+os.sep+'recompile.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript, '', '', ignoreErrors)
    

  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    
    
    ignoreErrors=False  
    if  parameterHelper.hasParameter('-ignore_errors')==True:
      ignoreErrors=True
    print ignoreErrors      

    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()

    oracleSid=parameterHelper.getParameterValue(['-s=','--sid='],[])
    projectHelper.failOnEmpty(oracleSid,'no oracle sid was given.')
    configReader.failOnValueNotFound('ORACLE_SIDS',oracleSid,'the given oracle sid is not valid for this project.')
    oracleSid=oracleSid[0]
    
    schemes=configReader.getValue('SCHEMES')
    projectHelper.failOnNone(schemes,'the variable SCHEMES is not set.')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    environment=configReader.getValue('DEFAULT_ENVIRONMENT')
    environment=parameterHelper.getParameterValue(['-e=','--env='],[environment])
    projectHelper.failOnEmpty(environment,'no environment was found')
    configReader.failOnValueNotFound('ENVIRONMENTS',environment,'the given environment is not valid for this project.')
    environment=environment[0]

    objects = configReader.getValue('CREATE_OBJECTS')
    projectHelper.failOnNone(objects,'the variable CREATE_OBJECTS is not set.')
    projectHelper.failOnEmpty(objects,'the variable CREATE_OBJECTS is not set.')

    for scheme in schemes:
      print "creating scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
      oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
      oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
 
      for object in objects:  

        # global ddl objects
        folder=self.getCreateDir()+os.sep+scheme+os.sep+'ddl'+os.sep+object
        if projectHelper.folderPresent(folder):
          self.installFiles(folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors)

        # environment specific ddl objects
        folder=self.getCreateDir()+os.sep+scheme+os.sep+'ddl'+os.sep+object+os.sep+environment
        if projectHelper.folderPresent(folder):
          self.installFiles(folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors)

      # global dat objects
      folder=self.getCreateDir()+os.sep+scheme+os.sep+'dat'
      if projectHelper.folderPresent(folder):
        self.installFiles(folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors)

      # environment specific dat objects
      folder=self.getCreateDir()+os.sep+scheme+os.sep+'dat'+os.sep+environment
      if projectHelper.folderPresent(folder):
        self.installFiles(folder, oracleSid, oracleUser, oraclePasswd, ignoreErrors)
        
      # global sqlldr files
      folder=self.getCreateDir()+os.sep+scheme+os.sep+'sqlldr'
      if projectHelper.folderPresent(folder):
        ctlFolders = projectHelper.findFolders(folder)
        for ctlFolder in ctlFolders:
          ctlFile = folder+os.sep+ctlFolder+os.sep+ctlFolder+".ctl"
          self.loadFiles(folder+os.sep+ctlFolder, oracleSid, oracleUser, oraclePasswd, ctlFile, ignoreErrors)


      # environment sqlldr files
      folder=self.getCreateDir()+os.sep+scheme+os.sep+'sqlldr'
      if projectHelper.folderPresent(folder):
        ctlFolders = projectHelper.findFolders(folder)
        for ctlFolder in ctlFolders:
          ctlFile = folder+os.sep+ctlFolder + os.sep + environment + os.sep + ctlFolder+ ".ctl"
          envFolder=folder + os.sep + ctlFolder + os.sep + environment
          if projectHelper.folderPresent(envFolder):          
            self.loadFiles(envFolder, oracleSid, oracleUser, oraclePasswd, ctlFile, ignoreErrors)

          
    
      print "scheme '"+scheme+"' created."

    if  parameterHelper.hasParameter('-nocompile')==False:
      for scheme in schemes:
        print "compiling scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
        oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
        oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
        self.recompile(oracleSid,oracleUser,oraclePasswd, ignoreErrors)
        print "scheme '"+scheme+"' compiled."





#!/usr/bin/env python
from org.noora.io.Loadable import Loadable 


class XmlPropertyLoader(Loadable):
  def __init__(self, properties):
    Loadable.__init__(self)
    self.__properties = properties

  def getProperties(self):
    return self.__properties
    
    
  def load(self, fileReader = None):
    properties = self.getProperties()
    
    tree = fileReader.read()
    lines = lines.split(chr(10))
    buffer=[]
    for line  in lines:
      if len(line)!=0 and line.startswith("#")==False:
        buffer.append(line)

    property = None
    for line in buffer:
      pairs=line.split("=",1)
      
      if len(pairs)==2:
        key = pairs[0]
        value  = pairs[1].strip()
        property = properties.setProperty(key, value)
      if len(pairs)==1:
        key = property.getKey()
        value = property.getValue() + pairs[0].strip()
        property = properties.setProperty(key, value)
    return properties
  

       





import wx
import AbstractPanel as AbstractPanel

class HeaderPanel(AbstractPanel.AbstractPanel):

  def getDescriptionControl(self):
    return self.__descriptionStaticText

  def __init__(self, parent, id, name, description):
    AbstractPanel.AbstractPanel.__init__(self, parent, id)
    
    sizer=wx.BoxSizer(wx.VERTICAL)  
    self.__nameStaticText = wx.StaticText(self, id, name)      
    font=wx.Font(10, wx.DEFAULT, wx.NORMAL, wx.BOLD)
    self.__nameStaticText.SetFont(font)
    
    self.__descriptionStaticText = wx.StaticText(self, id, description,style=wx.BOLD)
    
    
    sizer.Add(self.__nameStaticText,1,wx.ALL,10)  
    sizer.Add(self.__descriptionStaticText,1,wx.ALL,10)
    self.SetSizer(sizer)    
    self.SetBackgroundColour('WHITE')



import os.path

import core.config.ConfigReaderXML
import core.config.ConfigReaderProperty

CONFIG_TYPE_UNKNOWN = 1
CONFIG_TYPE_PROPERTY = 2
CONFIG_TYPE_XML = 3

CONFIG_FILE_PROPERTY = "project.conf"
CONFIG_FILE_XML = "project-config.xml"

CONFIG_STATUS_OK = 1
CONFIG_STATUS_ERROR = 2

# do not change config-file type 
CONFIG_POLICY_UNCHANGED = 1
# upgrade project.conf to project-config.xml
CONFIG_POLICY_UPGRADE = 2
# downgrade project-config.xml to project.conf
CONFIG_POLICY_DOWNGRADE = 3

class Config:

    def __init__(self, projectdir):
        self.__projectdir = projectdir
        self.__configFile, self.__configType = self.__getConfigFileInfo()

        confFile = "%s%c%s" % (self.__projectdir, os.path.sep, self.__configFile)

        if self.__configType == CONFIG_TYPE_XML:
            self.__configReader = core.config.ConfigReaderXML(confFile)
        if self.__configType == CONFIG_TYPE_PROPERTY:
            self.__configReader = core.config.ConfigReaderProperty(confFile)
        if self.__configType == CONFIG_TYPE_UNKNOWN:
            self.status = CONFIG_STATUS_ERROR
            return

        self.status = CONFIG_STATUS_OK

    def load(self):
        if self.__status == CONFIG_STATUS_OK:
            self.__configReader.load()

    def __getConfigFileInfo(self):
        if self.__hasConfigFile(CONFIG_FILE_XML) == True:
            return (CONFIG_FILE_XML, CONFIG_TYPE_XML);
        if self.__hasConfigFile(CONFIG_FILE_PROPERTY) == True:
            return (CONFIG_FILE_PROPERTY, CONFIG_TYPE_PROPERTY);
        return (None, CONFIG_TYPE_UNKNOWN)

    def __hasConfigFile(self, configFile):
        if (os.path.exists(configFile) and os.path.isfile(self.configFile)):
            return True
        return False




import core.config.ConfigReader as ConfigReader
from xml.etree.ElementTree import ElementTree

class ConfigReaderXML(ConfigReader):

    def __init__(self, filename):
        ConfigReader.ConfigReader.__init__(self, filename)

    def load(self):
        self.__tree = ElementTree()
        self.__tree.parse(self.__filename)
        if self.__tree == None:
            self.__status = ConfigReader.CR_STATUS_ERROR
            self.__message = "Invalid xml file"



#!/usr/bin/env python
from org.noora.io.File import File
import os
    
class Files:
  def __init__(self):
    pass
  
  def copy(self, fileReader, fileWriter):
    stream = fileReader.read()
    fileReader.close()
    
    fileWriter.write(stream)
    fileWriter.close()
    
  def move(self, fileReader, fileWriter):
    stream = fileReader.read()
    fileReader.close()
    
    fileWriter.write(stream)
    fileWriter.close()
    
    file = fileReader.getFile()
    file.delete()
  
  @staticmethod
  def list(file=None,recursive=False, exclude=None):
    result=[]
    
    if file.exists():
      folder = file.getPath()+os.sep+file.getName()
      fileList=os.listdir(folder)
      for fileItem in fileList:
        pathName = folder + os.sep + fileItem
        candidateFile = File(pathName)
        if candidateFile.isFile() and exclude!="file":          
          result.append(candidateFile)
        if candidateFile.isDirectory() and exclude!="directory":
          result.append(candidateFile)
        if candidateFile.isDirectory() and recursive==True:
          recursiveFiles = Files.list(candidateFile, recursive, exclude)
          for recursiveFile in recursiveFiles:
            result.append(recursiveFile)
      #result.sort()
    return result

  
  def delete(self, file=None, recursive=False):
    if file.isFile():
      file.delete()
    if file.isDirectory() and recursive==False:
      file.delete()
    if file.isDirectory() and recursive==True:
      foundFiles=self.listFiles(file, recursive)
      for foundFile in foundFiles:
        foundFile.delete()

      foundDirectories=self.listDirectories(file)
      foundDirectories.reverse()
      for foundDirectory in foundDirectories:
        foundDirectory.delete()

      file.delete()    


       





#!/usr/bin/env python
from org.noora.cl.Option import Option
from org.noora.io.FileFolderFilter import FileFolderFilter
from org.noora.io.FileFilter import FileFilter
from org.noora.io.FileExtensionFilter import FileExtensionFilter


class FilterSelector:

  def __init__(self):
    pass
  
  @staticmethod
  def select(file = None):
    return FileFolderFilter(file) 
  
  

class FilterFactory:
  def __init__(self):
    pass
  
  @staticmethod
  def newFileFolderFilter(file = None):
    return FileFolderFilter(file) 

  @staticmethod
  def newFileExtensionFilter(file = None):
    return FileExtensionFilter(file) 
  
  @staticmethod
  def newFileFilter(file = None):
    return FileFilter(file) 



#!/usr/bin/env python

import os
import subprocess

class StartupInfoFactory:
  def __init__(self):
    pass
  
  @staticmethod
  def newStartupInfo():
    startupInfo=None
    if os.name=='nt':    
      startupInfo=subprocess.STARTUPINFO()
      #USESHOWWINDOW
      startupInfo.dwFlags |=1
      #SW_HIDE
      startupInfo.wShowWindow=0
    return startupInfo


#!/usr/bin/env python
import logging

from org.noora.connector.Connector import Connector
from org.noora.io.File import File
from org.noora.io.FileReader import FileReader
from org.noora.io.Properties import Properties
from org.noora.parser.Parser import Parser
from org.noora.parser.PreProcessor import PreProcessor
from org.noora.io.FileWriter import FileWriter
from org.noora.processor.StartupInfoFactory import StartupInfoFactory
from org.noora.processor.Processor import Processor
from org.noora.processor.Call import Call

class MysqlConnector(Connector):
  
  def __init__(self):
    Connector.__init__(self)
    self.__processorResult = None
    
  def setProcessorResult(self, processorResult):
    self.__processorResult = processorResult
    
  def getProcessorResult(self):
    return self.__processorResult    
  
  def execute(self, executable, properties):
    
    script = executable.getScript()
    scriptReader = FileReader(script) 
      
    cp = Properties()
    cp.setProperty('database', executable.getDatabase())
    cp.setProperty('environment', properties.getPropertyValue('environment'))      
    parser = Parser(scriptReader,cp)      
    preProcessor = PreProcessor()
    stream = preProcessor.parse(parser)
    
    tmp = File("tmp.sql")
    tmpWriter = FileWriter(tmp)
    tmpWriter.write(stream)
    tmpWriter.close()
    
    scriptReader = FileReader(tmp)
    
    feedback = File('feedback.log')
    feedbackWriter = FileWriter(feedback) 
    
    startupInfo = StartupInfoFactory.newStartupInfo()      
    
    cp = Properties()
    cp.setProperty(Processor.STDERR, feedbackWriter)
    cp.setProperty(Processor.STDIN,scriptReader)
    cp.setProperty(Processor.STDOUT, feedbackWriter)
    cp.setProperty(Processor.STARTUPINFO, startupInfo)
    cp.setProperty(Processor.ARGUMENT, ["mysql","--show-warnings","--host="+executable.getHost(),"--user="+executable.getUsername(),"--password="+executable.getPassword(),executable.getDatabase()])
    cp.setProperty(Processor.SHELL, False)
    mysqlCall= Call(cp)
          
    processor = Processor()
    processorResult = processor.call(mysqlCall)
    self.setProcessorResult(processorResult)
         
    logger = logging.getLogger('NoOraLogger')
    logger.info(executable.getScript())

      







from org.noora.connector.MysqlConnector import MysqlConnector
from org.noora.connector.OracleConnector import OracleConnector

class ConnectorFactory:
  def __init__(self):
    pass
  
  @staticmethod
  def newMysqlConnector():
    return MysqlConnector() 
  
  @staticmethod
  def newOracleConnector():
    return OracleConnector() 
  


#!/usr/bin/env python


class Property:
  
  def __init__(self, key, value):
    self.__key = key
    self.__value = value
    
  def getKey(self):
    return self.__key
  
  def getValue(self):
    return self.__value
  
  def setValue(self, value):
    self.__value = value



       






import wx
import wx.lib.filebrowsebutton

__revision__ = "$Revision$"

[wxID_PROJECTGROUP, 
 wxID_PROJECTDIR, 
 wxID_PROJECTDIRLABEL,
] = [wx.NewId() for _init_ctrls in range(3)]

class Project:
    '''
    Create and manage the Project settings.
    Contains a directory chooser widget to locate the root directory of the noora project
    that you want to use
    '''
    
    def __init_controls(self, parent):
        
        self.__parent = parent
               
        # not all wx implementations (e.g. wxGTK) will support children _inside_ the static box so
        # we make them siblings of the static box instead.
        
        self.ProjectGroup = wx.StaticBox(id=wxID_PROJECTGROUP, label='Project', 
                                         name='ProjectGroup', parent=parent, 
                                         pos=wx.Point(8, 16), size=wx.Size(320, 104),
                                         style=0)

        #self.projectDirLabel = wx.StaticText(id=wxID_PROJECTDIRLABEL, label='Project home directory:',
        #                                     name='ProjectHomeLabel', parent=parent,
        #                                     pos=wx.Point(16, 32), size=wx.Size(64, 13),
        #                                     style=0)

        self.projectDir = wx.lib.filebrowsebutton.DirBrowseButton(buttonText='Browse',
                                                                  dialogTitle='Choose directory',
                                                                  id=wxID_PROJECTDIR,
                                                                  labelText='',
                                                                  newDirectory=False,
                                                                  parent=parent, 
                                                                  pos=wx.Point(24, 56),
                                                                  size=wx.Size(296, 48),
                                                                  startDirectory='.',
                                                                  style=wx.TAB_TRAVERSAL,
                                                                  toolTip='Type directory name or browse to select')
        self.projectDir.SetLabel('')
        self.projectDir.SetValue('')
        self.projectDir.SetName('projectDir')
        self.projectDir.SetToolTipString('choose project directory')
        # self.projectDir.Bind(WX_EVTBUTTON,)

    def __init__(self, parent):
        self.__init_controls(parent)



#!/usr/bin/env python
from org.noora.cl.Parseable import Parseable
from org.noora.cl.CommandLine import CommandLine


class PosixParser(Parseable):
  def __init__(self):
    Parseable.__init__(self)
    
  def parse(self, options=None, arguments=None): 
    commandLine = CommandLine()
    for argument in arguments:      
      values = argument.split('=')
      if options.hasOption(values[0])==True:
        option = options.getOption(values[0])          
        option.setValues(values[1:])
        commandLine.addOption(option)
        
    return commandLine


import wx
import panels.BrowsePanel           as BrowsePanel
import panels.TextPanel             as TextPanel
import panels.CancelFinishPanel     as CancelFinishPanel
import panels.HeaderPanel           as HeaderPanel
import gui.Settings                 as Settings

class NewProjectDialog(wx.Dialog):

    def getProjectControl(self):
      return self.__projectControl
    
    def getBrowseControl(self):
      return self.__browseControl
    
    def getDatabaseControl(self):
      return self.__databaseControl
    
    def getSchemeControl(self):
      return self.__schemeControl
    
    def getUsernameControl(self):
      return self.__usernameControl
    
    def getPasswordControl(self):
      return self.__passwordControl

    def getVersionControl(self):
      return self.__versionControl
    
    def getProject(self):
      projectControl=self.getProjectControl()
      return projectControl.getValue()
    
    def getDirectory(self):
      browseControl=self.getBrowseControl()
      return browseControl.getValue()

    def getDatabase(self):
      databaseControl=self.getDatabaseControl()
      return databaseControl.getValue()

    def getScheme(self):
      schemeControl=self.getSchemeControl()
      return schemeControl.getValue()

    def getUsername(self):
      usernameControl=self.getUsernameControl()
      return usernameControl.getValue()

    def getPassword(self):
      passwordControl=self.getPasswordControl()
      return passwordControl.getValue()

    def getVersion(self):
      versionControl=self.getVersionControl()
      return versionControl.getValue()



        
    def __init__(self, parent, id, title):
        
        wx.Dialog.__init__(self, parent, id, title, style=wx.DEFAULT_DIALOG_STYLE|wx.THICK_FRAME|wx.RESIZE_BORDER|wx.TAB_TRAVERSAL)

        sizer = wx.BoxSizer(wx.VERTICAL)
        self.__headerPanel = HeaderPanel.HeaderPanel(self, -1,"NoOra Project","Create a new NoOra Project")
        self.__projectControl=TextPanel.TextPanel(self,-1,"Project name:")
        self.__browseControl = BrowsePanel.BrowsePanel(self,-1,"Directory")
        self.__databaseControl = TextPanel.TextPanel(self,-1,"Database")
        self.__schemeControl = TextPanel.TextPanel(self,-1,"Scheme")
        self.__usernameControl = TextPanel.TextPanel(self,-1,"Username")
        self.__passwordControl = TextPanel.TextPanel(self,-1,"Password")
        self.__versionControl = TextPanel.TextPanel(self,-1,"Version")
        self.__cancelFinishControl=CancelFinishPanel.CancelFinishPanel(self,-1)
        
        sizer.Add(self.__headerPanel,0,wx.EXPAND)   
        sizer.Add(self.__projectControl,0,wx.ALL|wx.EXPAND,5)
        sizer.Add(self.__browseControl,0,wx.ALL|wx.EXPAND,5)
        sizer.Add(self.__databaseControl,0,wx.ALL|wx.EXPAND,5)
        sizer.Add(self.__schemeControl,0,wx.ALL|wx.EXPAND,5)
        sizer.Add(self.__usernameControl,0,wx.ALL|wx.EXPAND,5)
        sizer.Add(self.__passwordControl,0,wx.ALL|wx.EXPAND,5)
        sizer.Add(self.__versionControl,0,wx.ALL|wx.EXPAND,5)
        
        sizer.Add(self.__cancelFinishControl,0,wx.ALIGN_RIGHT|wx.ALL,5)

                
        self.SetSizer(sizer)
        self.SetMinSize((460,380))

        
        self.Bind(wx.EVT_BUTTON, self.onCancel, id=Settings.ID_CANCEL)
        self.Bind(wx.EVT_BUTTON, self.onFinish, id=Settings.ID_FINISH)
        self.Bind(wx.EVT_BUTTON, self.onOpen, id=Settings.ID_OPEN)
        
        self.__versionControl.setValue("1.0.0")

    def onCancel(self, evt):
      self.EndModal(Settings.ID_CANCEL)
            
    def onFinish(self, evt): 
      self.EndModal(Settings.ID_FINISH)
 

    def onOpen(self, evt): 
      dirDialog = wx.DirDialog(self, "Choose a directory:", style=wx.DD_DEFAULT_STYLE | wx.DD_NEW_DIR_BUTTON)  
      if dirDialog.ShowModal() == wx.ID_OK:
        dirname=dirDialog.GetPath()
        self.__browseControl.setValue(dirname)    


#!/usr/bin/env python
from org.noora.connector.Connector import Connector

class MysqlConnectorStub(Connector):
  
  def __init__(self):
    Connector.__init__(self)
  
  def execute(self, executable, properties):
    pass


      







#!/usr/bin/env python

import core.Plugin          as Plugin
import core.VersionHelper   as VersionHelper
import core.NooraException  as NooraException
import core.ClassLoader     as ClassLoader
import core.ParameterHelper as ParameterHelper
import os
import sys
import subprocess
import traceback

class RecreatePlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("RECREATE")
    
    self.addParameterDefinition('database',['-s','-si','--sid'])
    self.addParameterDefinition('scheme',['-u','-sc','--scheme'])
    self.addParameterDefinition('environment',['-e','--env'])
    self.addParameterDefinition('version',['-m','--max'])
    
  def getDescription(self):
    return "recreates the database objects of the defined schemes."


  def getUsage(self):  
    print "NoOra database installer, recreate.py"
    print self.getDescription()
    print "-s= --sid=     required contains the tnsname of the database."
    print "-u= --scheme=  not required, contains the scheme of "
    print "               the database objects to drop."
    print "-e= --env=     not required, used for mapping "
    print "               the username and password."
    print "-nocompile     not required, disable the compilation of "
    print "               packages, triggers and views."  
    print "-m= --max=     not required, after the given version recreation will stop."
    print "-test          not required, executes the defined unit tests after recreation."


  def getMaxVersion(self,versions):
    return versions[len(versions)-1]
  
  def getDefaultVersion(self):
    configReader=self.getConfigReader()
    defaultVersion=configReader.getValue('DEFAULT_VERSION')
    return defaultVersion
  
  def getVersions(self, defaultVersion):
    projectHelper=self.getProjectHelper()    
    versions=[]
    alterFolder=projectHelper.getAlterFolder()
    if projectHelper.folderPresent(alterFolder):
      versions=projectHelper.findFolders(alterFolder)
    createFolder=projectHelper.getCreateFolder()
    if projectHelper.folderPresent(createFolder):
      versions.append(defaultVersion)
    #versionHelper=VersionHelper.VersionHelper(versions)
    #versions=versionHelper.sort()
    
    versions.sort()            
    return versions  
  
  def getPlugin(self, plugins, pluginType):
    classLoader = ClassLoader.ClassLoader()
    for plugin in plugins:
      pluginClass=classLoader.findByPattern(plugin)
      if pluginClass.getType().lower()==pluginType.lower():
        return pluginClass


  def addParameter(self, parameters, parameterType, parameterValue):
    if parameterValue:
      parameters.append(parameterType+parameterValue)
    return parameters
  
  def addOption(self, parameters, optionType):
    parameters.append(optionType)
    return parameters

  def dropDatabase(self, plugins, oracleSid, scheme, environment):
    try:
      dropPlugin = self.getPlugin(plugins, 'drop')
      parameters=[]
      parameters=self.addParameter(parameters, "--sid=", oracleSid)
      parameters=self.addParameter(parameters, "--scheme=", scheme)
      parameters=self.addParameter(parameters, "--env=", environment)
    
      parameterHelper=ParameterHelper.ParameterHelper()
      parameterHelper.setParameters(parameters)
      dropPlugin.execute(parameterHelper)
    except NooraException.NooraException as e:
      print e.getMessage()    
      exit(1)
    except Exception as e:
      print traceback.print_exc()
      exit(1)


  def createDatabase(self, plugins, oracleSid, scheme, environment):
    try:
      createPlugin = self.getPlugin(plugins, 'create')
      parameters=[]
      
      parameters=self.addParameter(parameters, "--sid=", oracleSid)
      parameters=self.addParameter(parameters, "--scheme=", scheme)
      parameters=self.addParameter(parameters, "--env=", environment)
      parameters=self.addOption(parameters, "-nocompile")
    
      parameterHelper=ParameterHelper.ParameterHelper()
      parameterHelper.setParameters(parameters)
      createPlugin.execute(parameterHelper)
    except NooraException.NooraException as e:
      print e.getMessage()    
      exit(1)
    except:
      print traceback.print_exc()
      exit(1)

  def updateDatabase(self, plugins, oracleSid, scheme, environment, versions, maxVersion):
    try:
      for version in versions:
        if version!=versions[0]:
        
          updatePlugin = self.getPlugin(plugins, 'update')
          parameters=[]
          parameters=self.addParameter(parameters, "--sid=", oracleSid)
          parameters=self.addParameter(parameters, "--scheme=", scheme)
          parameters=self.addParameter(parameters, "--env=", environment)
          parameters=self.addParameter(parameters, "--version=", version)
          parameters=self.addOption(parameters, "-nocompile")
    
          parameterHelper=ParameterHelper.ParameterHelper()
          parameterHelper.setParameters(parameters)
          updatePlugin.execute(parameterHelper)
          
        if version==maxVersion:
          break
          
    except NooraException.NooraException as e:
      print e.getMessage()    
      exit(1)
    except:
      print traceback.print_exc()
      exit(1)
      

  def recompile(self, oracleSid, oracleUser, oraclePasswd, ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getScriptDir()+os.sep+'recompile.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,'','', ignoreErrors)

  def unittest(self, oracleSid, oracleUser, oraclePasswd, ignoreErrors):
    connector=self.getConnector()
    oracleScript=self.getScriptDir()+os.sep+'unittest.sql'
    connector.execute(oracleSid, oracleUser, oraclePasswd, oracleScript,'','', ignoreErrors)



  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    

    ignoreErrors=False  
    if  parameterHelper.hasParameter('-ignore_errors')==True:
      ignoreErrors=True
    

    configReader=self.getConfigReader()
    projectHelper=self.getProjectHelper()

    oracleSid=parameterHelper.getParameterValue(['-s=','--sid='],[])
    projectHelper.failOnEmpty(oracleSid,'no oracle sid was given.')
    configReader.failOnValueNotFound('ORACLE_SIDS',oracleSid,'the given oracle sid is not valid for this project.')
    oracleSid=oracleSid[0]

    scheme=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],[""])
    scheme=scheme[0]
    
    
    schemes=configReader.getValue('SCHEMES')
    schemes=parameterHelper.getParameterValue(['-u=','--scheme=','--user='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    environment=configReader.getValue('DEFAULT_ENVIRONMENT')
    environment=parameterHelper.getParameterValue(['-e=','--env='],[environment])
    projectHelper.failOnEmpty(environment,'no environment was found')
    configReader.failOnValueNotFound('ENVIRONMENTS',environment,'the given environment is not valid for this project.')
    environment=environment[0]

    defaultVersion=self.getDefaultVersion()
    projectHelper.failOnEmpty(defaultVersion,'the variable DEFAULT_VERSION is not configured for this project.')

    # find the versions
    versions=self.getVersions(defaultVersion)
    
    maxVersion=self.getMaxVersion(versions)
    maxVersion=parameterHelper.getParameterValue(['-m=','--max='],[maxVersion])
    maxVersion=maxVersion[0]
    projectHelper.failOnValueNotFound(versions,maxVersion,'the given max version is not valid for this project.')
    
    plugins=configReader.getValue('PLUGINS')
    projectHelper.failOnNone(plugins,'the variable PLUGINS is not set.')
    projectHelper.failOnEmpty(plugins,'the variable PLUGINS is not set.')
        

    self.dropDatabase(plugins, oracleSid, scheme, environment)
    self.createDatabase(plugins, oracleSid, scheme, environment)
    self.updateDatabase(plugins, oracleSid, scheme, environment, versions, maxVersion)

    if  parameterHelper.hasParameter('-nocompile')==False:
      for scheme in schemes:
        print "compiling scheme '"+scheme+"' in database '"+oracleSid+"' using environment '"+environment+"'"
        oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
        oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
        self.recompile(oracleSid,oracleUser,oraclePasswd, ignoreErrors)
        print "scheme '"+scheme+"' compiled."

    if parameterHelper.hasParameter('-test')==True:
      for scheme in schemes:
        oracleUser=projectHelper.getOracleUser(oracleSid, scheme)
        oraclePasswd=projectHelper.getOraclePasswd(oracleSid, scheme)
        self.unittest(oracleSid, oracleUser, oraclePasswd, ignoreErrors)





#!/usr/bin/env python
from org.noora.io.IOException import IOException

class Loadable:  
  def __init__(self):
    pass
  
  def load(self, fileReader = None):  
    raise IOException("method not implemented")
  

       





import wx

ID_NEW_PROJECT   = 12000
ID_OPEN_PROJECT  = 12001
ID_CLOSE_PROJECT = 12002
ID_FINISH        = 12003
ID_CANCEL        = 12004
ID_OPEN          = 12005
ID_COMMAND       = 12006
ID_EDIT_PROJECT  = 12007
ID_EXECUTE       = 12008
ID_CLEAR         = 12009
ID_CLOSE             = 12010
ID_SHOW_ACTION_VIEW  = 12011
ID_SHOW_CONSOLE_VIEW = 12012
ID_APPLY             = 12013
ART_CONSOLE      = "ART_CONSOLE"
ART_ACTION       = "ART_ACTION"
EVT_PLUGIN_FINISHED = wx.NewEventType()



import wx
import core.CommandDispatcher as Dispatcher
import gui.panels.DirectoryPicker as DirPicker
import gui.panels.ChoicePanel as Choice

DIALOG_TYPE_NEW = 1
DIALOG_TYPE_OPEN = 2

class ProjectDialog(wx.Dialog):

    #def onGenerateProject(self, event):
        #command = Dispatcher.CommandDispatcher();
        
        
    def __init__(self, parent, id, title, dialogtype):
        
        wx.Dialog.__init__(self, parent, id, title, size=(350, 300))

        sizer = wx.BoxSizer(wx.VERTICAL)

        if dialogtype == DIALOG_TYPE_NEW:
            self.__button = wx.Button(self,-1,'Generate');
            sizer.Add(DirPicker.DirectoryPicker(self,wx.NewId()))
            sizer.Add(Choice.ChoicePanel(self,wx.NewId(),'Database',['Oracle','sqlite']))
            sizer.Add(self.__button, 0, wx.ALL | wx.ALIGN_CENTER)
            #wx.EVT_BUTTON(self, self.__button.GetId(), self.onGenerateProject)
            
        self.SetSizer(sizer)



import wx
import os
import sys
import Settings as Settings


NOORA_DIR    = os.path.abspath(os.path.dirname(sys.argv[0]))

class MainArtProvider(wx.ArtProvider):

  def __init__(self):        
    wx.ArtProvider.__init__(self)
    self.setNooraDir(NOORA_DIR)
 
  def CreateBitmap(self, artid, client, size):
    bmp = wx.NullBitmap
    if artid == wx.ART_FILE_OPEN:
      bmp=wx.Image(self.getResourceDir()+os.sep+'importdir_wiz.gif', wx.BITMAP_TYPE_GIF).ConvertToBitmap()
    if artid == wx.ART_NEW:
      bmp=wx.Image(self.getResourceDir()+os.sep+'new_project.gif', wx.BITMAP_TYPE_GIF).ConvertToBitmap()
    if artid == wx.ART_GO_FORWARD:
      bmp=wx.Image(self.getResourceDir()+os.sep+'run.gif', wx.BITMAP_TYPE_GIF).ConvertToBitmap()
    if artid == wx.ART_UNDO:
      bmp=wx.Image(self.getResourceDir()+os.sep+'clear_console.gif', wx.BITMAP_TYPE_GIF).ConvertToBitmap()
    if artid == Settings.ART_CONSOLE:
      bmp=wx.Image(self.getResourceDir()+os.sep+'console_view.gif', wx.BITMAP_TYPE_GIF).ConvertToBitmap()
    if artid == Settings.ART_ACTION:
      bmp=wx.Image(self.getResourceDir()+os.sep+'throbber.png', wx.BITMAP_TYPE_PNG).ConvertToBitmap()
    return bmp
  
  def setNooraDir(self, path):
    self.__nooraDir=path
    
  def getNooraDir(self):
    return self.__nooraDir

  def getResourceDir(self):
    return self.getNooraDir()+os.sep+'resources'
        


#!/usr/bin/env python

class StreamHelper:
  
  def __init__(self):
    pass

  def convert(self,stream):
    stream = stream.replace(chr(13)+chr(10),chr(10))
    stream = stream.replace(chr(13),chr(10)) 
    return stream




#!/usr/bin/env python

class Filters:

  def __init__(self):
    self.__filters = []

  def add(self, filterable):
    self.__filters.append(filterable)
  
  def list(self):
    return self.__filters    

  def accept(self, fileable):
    filters = self.__filters
    for filter in filters:
      if filter.accept(fileable):
        return True
    return False

    
       






CR_STATUS_NOT_LOADED = 1
CR_STATUS_LOADED = 2
CR_STATUS_ERROR = 3

class ConfigReader:


    def __init__(self, filename):
        self.__filename = filename
        self.__status = CR_STATUS_NOT_LOADED
        self.__message = None

    def load(self):
        self.__message = "Unsupported operation: load"

    def save(self):
        self.__message = "Unsupported operation: save"

    def getValue(self, path):
        self.__message = "Unsupported operation: getValue"

    def setValue(self, path, value):
        self.__message = "Unsupported operation: setValue"

    def hasValue(self, path):
        self.__message = "Unsupported operation: hasValue"

    def setFilename(self, filename):
        self.__filename = filename
        self.__status = CR_STATUS_NOT_LOADED
        self.__message = None

    def getFilename(self):
        return self.__filename

    def setStatus(self, status):
        self.__status = status

    def getStatus(self):
        return self.__status

    def setMessage(self, message):
        self.__message = message

    def getMessage(self):
        return self.__message



import wx
import gui.Settings as Settings

class PluginFinishedEvent(wx.PyEvent):
  """
    Open project event.
  """
  
  def getDirectory(self):
    return self.__directory
  
  def getFilename(self):
    return self.__filename

  def __init__(self, id, directory, filename):
    event_type = Settings.EVT_PLUGIN_FINISHED
    #wx.PyEvent.__init__(self, id=id, eventType=self.__eventType)
    wx.PyEvent.__init__(self, id, event_type)
    self.__directory = directory
    self.__filename = filename 


#!/usr/bin/env python
from org.noora.io.Readable import Readable
import os

class FileReader(Readable):
  def __init__(self, file=None):
    Readable.__init__(self)
    self.__file = file
    if file.getPath()!='':
      pathName = file.getPath() + os.sep + file.getName()
    else:
      pathName = file.getPath() + file.getName()
    self.__handle = open(pathName,'rb')

  def fileno(self):
    handle = self.__handle
    return handle.fileno()    
    
  def read(self):
    handle = self.__handle
    stream = handle.read()
    stream = stream.replace(chr(13)+chr(10),chr(10))
    stream = stream.replace(chr(13),chr(10)) 
    return stream
  
  def getFile(self):
    return self.__file
    
  def close(self):
    handle = self.__handle
    handle.close()
    

       





import wx
import AbstractPanel as AbstractPanel

class ChoicePanel(AbstractPanel.AbstractPanel):

  def getChoiceControl(self):
    return self.__choiceControl
  
  def getValue(self):
    choiceControl=self.getChoiceControl()
    return choiceControl.GetValue()
  
  def setValue(self, value):
    choiceControl=self.getChoiceControl()
    choiceControl.SetValue(value)
    
  def clear(self):
    choiceControl=self.getChoiceControl()
    choiceControl.Clear()
    
  def append(self, choice):
    choiceControl=self.getChoiceControl()
    choiceControl.Append(choice)
  

  def __init__(self, parent, id, label, choices):
    AbstractPanel.AbstractPanel.__init__(self, parent, id)
    
    sizer=wx.BoxSizer(wx.HORIZONTAL)  
    self.__staticText = wx.StaticText(self, id, label)  
    self.__staticText.SetMinSize((100,20))      
    self.__choiceControl=wx.Choice(self, id, choices=choices)
    sizer.Add(self.__staticText,0)  
    sizer.Add(self.__choiceControl,1)
    self.SetSizer(sizer)    



#!/usr/bin/env python
from org.noora.processor.Processable import Processable
from org.noora.processor.ProcessorException import ProcessorException
from org.noora.processor.ProcessorResult import ProcessorResult
from org.noora.io.FileReader import FileReader
import subprocess


class Processor(Processable):
  
  STDOUT          = "STDOUT"
  STDIN           = "STDIN"
  STDERR          = "STDERR"
  STARTUPINFO     = "STARTUPINFO"
  ARGUMENT        = "ARGUMENT"
  SHELL           = "SHELL"
  OK              = "OK"
  ERROR           = "ERROR"
  
  def __init__(self):
    Processable.__init__(self)
  
  def call(self, callable):
    try:
      shell = callable.getProperty(Processor.SHELL)
      stdout = callable.getProperty(Processor.STDOUT)
      stdin = callable.getProperty(Processor.STDIN)
      stderr = callable.getProperty(Processor.STDERR)
      startupinfo = callable.getProperty(Processor.STARTUPINFO)
      argument = callable.getProperty(Processor.ARGUMENT)
    
      result=subprocess.call(argument,shell=shell,stdout=stdout,stderr=stderr,stdin=stdin,startupinfo=startupinfo)
      if result!=0:
        file = stderr.getFile()
        reader = FileReader(file)
        stream = reader.read()     
        raise ProcessorException(stream)
      
      file = stdout.getFile()
      reader = FileReader(file)
      stream = reader.read()           
      return ProcessorResult(stream)
          
    except OSError:
      raise ProcessorException("Could not execute call. Is it installed and in your path?")

      
  
  







#!/usr/bin/env python
from org.noora.classloader.ClassLoadable import ClassLoadable
from org.noora.classloader.ClassLoaderException import ClassLoaderException
import sys

class ClassLoader(ClassLoadable):
    
  def __init__(self):
    ClassLoadable.__init__(self)    
    
  def find(self, moduleName,className):
    try:
      mod = __import__(moduleName ,globals(), locals(), [''])        
      clazz=getattr(mod,className)
        
      clazzInstance=clazz()
      return clazzInstance
    except:
      # sys.exc_info()[0] could be wrong
      message = ""
      for info in sys.exc_info():
        message = message + str(info)
      raise ClassLoaderException(message)
    
  def findByPattern(self, pattern):
    patternList = pattern.split(".")
    listLength=len(patternList)
    className=patternList[listLength-1]
    moduleName=".".join(patternList[0:listLength-1])
    return self.find(moduleName, className)

    
   
        



#!/usr/bin/env python
from org.noora.connector.Executable import Executable

__revision__ = "$Revision: $"


class Execute(Executable):

  def __init__(self):
    Executable.__init__(self)
    self.__ignoreErrors=False
    self.__script=None
        
  def setIgnoreErrors(self, ignoreErrors):
    self.__ignoreErrors=ignoreErrors

  def getIgnoreErrors(self):
    return self.__ignoreErrors
    
  def setScript(self, script):
    self.__script=script
    
  def getScript(self):
    return self.__script
    
    




#!/usr/bin/env python
from org.noora.io.Fileable import Fileable
import os

class File(Fileable):
  def __init__(self, pathName=None):
    Fileable.__init__(self)
    self.__pathName=pathName
    
  @staticmethod
  def pathSeperator():
    return os.sep    
    
  def exists(self):
    if self.isFile():
      return True
    if self.isDirectory():
      return True
    return False
      
  def notExists(self):
    if self.exists():
      return False
    return True
  
  def isFile(self):
    pathName = self.__pathName
    return os.path.isfile(pathName)
  
  def isDirectory(self):
    pathName = self.__pathName
    return os.path.isdir(pathName)
  
  def getName(self):
    pathName = self.__pathName
    folder,filename=os.path.split(pathName)
    return filename
  
  def getAbsolutePath(self):
    path = self.getPath()
    if path == None:
      return os.path.abspath('.')
    return path
  
  def getPath(self):
    pathName = self.__pathName
    folder,filename=os.path.split(pathName)
    return folder

  def getExtension(self):
    pathName = self.__pathName
    root,extension=os.path.splitext(pathName)
    return extension.lstrip('.')  
  
  def getRoot(self):
    pathName = self.__pathName
    root,extension=os.path.splitext(pathName)
    return root 

  def delete(self):
    pathName = self.__pathName
    if self.isFile():      
      os.remove(pathName)
    if self.isDirectory():
      os.rmdir(pathName)

       





#!/usr/bin/env python
from org.noora.app.AppException import AppException

class Appable:
  def __init__(self):
    pass
  
  def checkRequiredOptions(self):
    raise AppException("method not implemented")
    



#!/usr/bin/env python
from org.noora.connector.Connectable import Connectable
from org.noora.connector.ConnectorException import ConnectorException

__revision__ = "$Revision: $"

class Connector(Connectable):

  def __init__(self):
    Connectable.__init__(self)
    
  def execute(self, executable, properties):
    raise ConnectorException("method not implemented")

    



#!/usr/bin/env python

import core.Plugin as Plugin
import core.VersionHelper as VersionHelper
import core.ConfigReader  as ConfigReader
import os


class GeneratePlugin(Plugin.Plugin):
  def __init__(self):
    Plugin.Plugin.__init__(self)
    self.setType("GENERATE")
    self.setBaseDir(os.path.abspath('.'))
    
    self.addParameterDefinition('project',['-pr','--project'])
    self.addParameterDefinition('database',['-si','--sid'])
    self.addParameterDefinition('scheme',['-sc','--scheme'])
    self.addParameterDefinition('username',['-u','--username'])
    self.addParameterDefinition('password',['-p','--password'])
    self.addParameterDefinition('version',['-v','--version'])
  
  def getPluginDir(self):
    return self.getNooraDir()+os.sep+'plugins'+os.sep+'dynamic'+os.sep+'generate'

  def getDescription(self):
    return "intiates a new NoOra database project, or a new release of an existing database project."
  

  def getUsage(self):  
    print "NoOra database installer, GeneratePlugin"
    print self.getDescription()
    print "-pr= --project=   not required, contains the database project name."
    print "-si= --sid=       not required, contains the oracle sid."
    print "-sc= --scheme=    not required, contains the scheme name."
    print "-u= --username=   not required, contains the username."
    print "-p= --password=   not required, contains the password."
    print "-v= --version=    required, contains the version to create."
    
  def getDefaultVersion(self):
    configReader=self.getConfigReader()
    defaultVersion=configReader.getValue('DEFAULT_VERSION')
    return defaultVersion

  def getVersions(self, defaultVersion):
    projectHelper=self.getProjectHelper()    
    versions=[]
    alterFolder=projectHelper.getAlterFolder()
    if projectHelper.folderPresent(alterFolder):
      versions=projectHelper.findFolders(alterFolder)
    createFolder=projectHelper.getCreateFolder()
    if projectHelper.folderPresent(createFolder):
      versions.append(defaultVersion)
    versionHelper=VersionHelper.VersionHelper(versions)
    versions=versionHelper.sort()
    return versions


  def getSqlVersionStatement(self, versions, version):
    configReader=self.getConfigReader()
    createVersion=versions[0]
    if createVersion==version: 
      stream=configReader.getValue('VERSION_INSERT_STATEMENT')
    else:
      stream=configReader.getValue('VERSION_UPDATE_STATEMENT')
      stream=stream.replace('<version>',version)
    return stream

  
  def getSqlEnvironmentStatement(self, environment):
    configReader=self.getConfigReader()
    stream=configReader.getValue('ENVIRONMENT_INSERT_STATEMENT')
    stream=stream.replace('<environment>',environment)
    return stream


  def execute(self, parameterHelper):
    if parameterHelper.hasParameter('-h'):
      self.getUsage()
      exit(1)    

    projectHelper=self.getProjectHelper()

    version=parameterHelper.getParameterValue(['-v=','--version='],[])

    if projectHelper.fileNotPresent('project.conf'):

      projectFolder=parameterHelper.getParameterValue(['-pr=','--project='],[])
      projectHelper.failOnEmpty(projectFolder,'no project is given, use the -pr= option')
      projectFolder=projectFolder[0]

      oracleSid=parameterHelper.getParameterValue(['-si=','--sid='],[])
      projectHelper.failOnEmpty(oracleSid,'no oracle sid is given, use the -si option')
      oracleSid=oracleSid[0]

      scheme=parameterHelper.getParameterValue(['-sc=','--scheme='],[])
      projectHelper.failOnEmpty(scheme,'no scheme is given, use the -sc option')
      scheme=scheme[0]

      oracleUser=parameterHelper.getParameterValue(['-u=','--username='],[])
      projectHelper.failOnEmpty(oracleUser,'no username is given, use the -u option')
      oracleUser=oracleUser[0]

      oraclePasswd=parameterHelper.getParameterValue(['-p=','--password='],[])
      projectHelper.failOnEmpty(oraclePasswd,'no username is given, use the -p option')
      oraclePasswd=oraclePasswd[0]
      
      projectHelper.failOnEmpty(version,'no version is given, use the -v option')

      projectHelper.failOnFolderPresent(projectFolder,'the given project is already present')

      # create the project folder
      os.makedirs(projectFolder)
      
      # create the project.conf file
      filename='project.conf'
      folder=self.getPluginDir()+os.sep+'templates'
      sourceFile=folder+os.sep+filename
      targetFile=projectFolder+os.sep+filename
      projectHelper.copyFile(sourceFile,targetFile)
      stream=projectHelper.readFile(targetFile)
      stream=stream.replace('<SID>',oracleSid)
      stream=stream.replace('<SCHEME>',scheme)
      stream=stream.replace('<USERNAME>',oracleUser)
      stream=stream.replace('<PASSWORD>',oraclePasswd)
      stream=stream.replace('<VERSION>',version[0])
      projectHelper.writeFile(targetFile,stream)

      os.chdir(projectFolder)
      self.setBaseDir(os.path.abspath('.'))
      projectHelper.setBaseDir(os.path.abspath('.'))

      print "project "+projectFolder+" created."
      
      
    configReader=ConfigReader.ConfigReader('project.conf')
    self.setConfigReader(configReader)
    projectHelper.setConfigReader(configReader)
    #configReader=self.getConfigReader()
    
    schemes=configReader.getValue('SCHEMES')
    schemes=parameterHelper.getParameterValue(['-sc=','--scheme='],schemes)
    configReader.failOnValueNotFound('SCHEMES',schemes,'the given scheme is not valid for this project.')

    versionScheme=configReader.getValue('VERSION_SCHEME')
    projectHelper.failOnEmpty(versionScheme,'the variable VERSION_SCHEME is not configured for this project.')

    versionInsertStatement=configReader.getValue('VERSION_INSERT_STATEMENT')
    projectHelper.failOnEmpty(versionInsertStatement,'the variable VERSION_INSERT_STATEMENT is not configured for this project.')

    versionUpdateStatement=configReader.getValue('VERSION_UPDATE_STATEMENT')
    projectHelper.failOnEmpty(versionUpdateStatement,'the variable VERSION_UPDATE_STATEMENT is not configured for this project.')

    environments=configReader.getValue('ENVIRONMENTS')
    projectHelper.failOnEmpty(environments,'the variable ENVIRONMENTS is not configured for this project.')

    defaultVersion=self.getDefaultVersion()
    projectHelper.failOnEmpty(defaultVersion,'the variable DEFAULT_VERSION is not configured for this project.')


    # find the versions
    versions=self.getVersions(defaultVersion)
        
    if len(version)==0:
      versionHelper=VersionHelper.VersionHelper(versions)
      version.append(versionHelper.getNextRevision(defaultVersion))    
   
    version=version[0]
    
    if len(versions)==0:
      versions.append(defaultVersion)
    
    
    versionFolder=projectHelper.getBuildFolder(versions, version)
    projectHelper.failOnFolderPresent(versionFolder,'the given version is already present')

    objects=configReader.getValue('CREATE_OBJECTS')
    projectHelper.failOnNone(objects,'the variable CREATE_OBJECTS is not configured for this project.')

    # create the version folder
    os.makedirs(versionFolder)
  
    for scheme in schemes:

      # create the scheme folder
      schemeFolder=versionFolder+os.sep+scheme
      os.mkdir(schemeFolder)

      # create the dat folder
      datFolder=schemeFolder+os.sep+'dat'
      os.mkdir(datFolder)

      # create the version script in the dat folder
      if scheme==versionScheme:
        sqlScript=self.getSqlVersionStatement(versions, version)
        projectHelper.writeFile(datFolder+os.sep+'version.sql', sqlScript)

      # create the environment folders in the dat folder
      for environment in environments:
        os.mkdir(datFolder+os.sep+environment)

        # create the environment script in the dat folder.
        if scheme==versionScheme and versions[0]==version:
          sqlScript=self.getSqlEnvironmentStatement(environment)
          projectHelper.writeFile(datFolder+os.sep+environment+os.sep+'environment.sql', sqlScript)
                

      # create the ddl folder
      ddlFolder=schemeFolder+os.sep+'ddl'
      os.mkdir(ddlFolder)

      # create the object folders in the ddl folder
      for object in objects:
        os.mkdir(ddlFolder+os.sep+object)
      
      # create the template code on create.
      if scheme==versionScheme and versions[0]==version:
      
        files=projectHelper.findFiles(folder)
        for object in objects:
          folder=self.getPluginDir()+os.sep+'templates'+os.sep+object
          if projectHelper.folderPresent(folder):
            files=projectHelper.findFiles(folder)
            for file in files:
              sourceFile=folder+os.sep+file
              targetFile=ddlFolder+os.sep+object+os.sep+file
              projectHelper.copyFile(sourceFile,targetFile)

    print "version "+version+" created."




#!/usr/bin/env python

import core.Connector as Connector
import os
import subprocess


class SqlLoaderConnectorStub(Connector.Connector):
  
  def __init__(self):
    Connector.Connector.__init__(self)
  
  def getScriptDir(self):
    return self.getNooraDir()+os.sep+'scripts'
  
  def showErrors(self):
    try:
      projectHelper=self.getProjectHelper()
      stream=projectHelper.readFile('feedback.log')
      print stream
    except:
      exit(1)

  def execute(self, oracleSid, oracleUser, oraclePasswd, ctlFile, dataFile, ignoreErrors):
    pass







#!/usr/bin/env python
from org.noora.version.VersionFactory import VersionFactory

class Versions:
  
  def __init__(self):
    self.__versions=[]
       
  def clear(self):
    self.__versions=[]
      
  def getVersions(self):
    return self.__versions
  
  def add(self, version):
    self.__versions.append(version)
  
  def addVersion(self, major=None, minor=None, revision=None, patch=None):
    version = VersionFactory.newVersion(major, minor, revision, patch)
    self.__versions.append(version)
    return version
  
  def lastVersion(self):
    versions = self.__versions
    return versions[len(versions)-1]
  
  def previousVersion(self, other):
    versions = self.__versions
    i = 0
    for version in versions:
      if version == other:
        return versions[i-1]
      i = i + 1
    
      
  def sort(self):
    versions = self.__versions  
    versions.sort(key=lambda version:version.list())
              
  
  def size(self):
    versions = self.__versions
    return len(versions)
  


